@@ -156,7 +156,6 @@ except ImportError:
 
 from collections import namedtuple
 from ansible.plugins.inventory import BaseInventoryPlugin, Constructable, Cacheable
-from ansible.module_utils.six import iteritems
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMAuth
 from ansible.errors import AnsibleParserError, AnsibleError
 from ansible.module_utils.parsing.convert_bool import boolean
@@ -197,11 +196,11 @@ class AzureRMRestConfiguration(Configuration):
         if not base_url:
             base_url = 'https://management.azure.com'
 
-        credential_scopes = base_url + '/.default'
+        credential_scopes = [f"{base_url}/.default"]
 
         super(AzureRMRestConfiguration, self).__init__()
 
-        self.authentication_policy = BearerTokenCredentialPolicy(credentials, credential_scopes)
+        self.authentication_policy = BearerTokenCredentialPolicy(credentials, *credential_scopes)
         self.credentials = credentials
         self.subscription_id = subscription_id
 
@@ -431,7 +430,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             # FUTURE: configurable default IP list? can already do this via hostvar_expressions
             self.inventory.set_variable(inventory_hostname, "ansible_host",
                                         next(chain(hostvars['public_ipv4_address'], hostvars['private_ipv4_addresses']), None))
-            for k, v in iteritems(hostvars):
+            for k, v in hostvars.items():
                 # FUTURE: configurable hostvar prefix? Makes docs harder...
                 self.inventory.set_variable(inventory_hostname, k, v)
 
@@ -849,6 +848,9 @@ class AzureHost(object):
             new_hostvars['virtual_machine_memoryMB'] = self._vm_model['properties']['hardwareProfile'].get('memoryMB')
             new_hostvars['virtual_machine_processors'] = self._vm_model['properties']['hardwareProfile'].get('processors')
 
+        rm_endpoint = self._inventory_client.azure_auth._cloud_environment.endpoints.resource_manager.rstrip('/')
+        scopes = [f"{rm_endpoint}/.default"]
+
         if len(self.nics) == 0 and self._vmss:
             # Set the attribute information related to the Uniform VMSS instance
             # Set os compute name, os name, os version and hyper V generation
@@ -856,7 +858,8 @@ class AzureHost(object):
             vmss_name = new_hostvars['vmss']['name']
             instance_id = self._vm_model.get('instanceId')
             compute_client = ComputeManagementClient(credential=self._inventory_client.azure_auth.azure_credential_track2,
-                                                     subscription_id=self._inventory_client.azure_auth.subscription_id)
+                                                     subscription_id=self._inventory_client.azure_auth.subscription_id,
+                                                     base_url=rm_endpoint, credential_scopes=scopes)
             instance_view = compute_client.virtual_machine_scale_set_vms.get_instance_view(resource_group_name=resource_group,
                                                                                            vm_scale_set_name=vmss_name,
                                                                                            instance_id=instance_id)
@@ -867,7 +870,8 @@ class AzureHost(object):
 
             # Set Uniform VMSS instance's nic-related values
             network_client = NetworkManagementClient(credential=self._inventory_client.azure_auth.azure_credential_track2,
-                                                     subscription_id=self._inventory_client.azure_auth.subscription_id)
+                                                     subscription_id=self._inventory_client.azure_auth.subscription_id,
+                                                     base_url=rm_endpoint, credential_scopes=scopes)
             nics = network_client.network_interfaces.list_virtual_machine_scale_set_vm_network_interfaces(resource_group_name=resource_group,
                                                                                                           virtual_machine_scale_set_name=vmss_name,
                                                                                                           virtualmachine_index=instance_id)
@@ -934,7 +938,8 @@ class AzureHost(object):
 
             # Set os compute name, os name, os version and hyper V generation
             compute_client = ComputeManagementClient(credential=self._inventory_client.azure_auth.azure_credential_track2,
-                                                     subscription_id=self._inventory_client.azure_auth.subscription_id)
+                                                     subscription_id=self._inventory_client.azure_auth.subscription_id,
+                                                     base_url=rm_endpoint, credential_scopes=scopes)
             instance_view = compute_client.virtual_machines.instance_view(new_hostvars['resource_group'], new_hostvars['name'])
             new_hostvars['os_compute_name'] = instance_view.computer_name
             new_hostvars['os_name'] = instance_view.os_name
