@@ -68,7 +68,8 @@ class NetworksWirelessSsidsFirewallL3FirewallRules(object):
     def update_all_params(self):
         new_object_params = {}
         if self.new_object.get('allowLanAccess') is not None or self.new_object.get('allow_lan_access') is not None:
-            new_object_params['allowLanAccess'] = self.new_object.get('allowLanAccess')
+            new_object_params['allowLanAccess'] = self.new_object.get(
+                'allowLanAccess')
         if self.new_object.get('rules') is not None or self.new_object.get('rules') is not None:
             new_object_params['rules'] = self.new_object.get('rules') or \
                 self.new_object.get('rules')
@@ -109,7 +110,8 @@ class NetworksWirelessSsidsFirewallL3FirewallRules(object):
         prev_obj = None
         id_exists = False
         name_exists = False
-        o_id = self.new_object.get("networkId") or self.new_object.get("network_id")
+        o_id = self.new_object.get(
+            "networkId") or self.new_object.get("network_id")
         name = self.new_object.get("name")
         if o_id:
             prev_obj = self.get_object_by_name(o_id)
@@ -190,7 +192,8 @@ class ActionModule(ActionBase):
         self._check_argspec()
 
         meraki = MERAKI(self._task.args)
-        obj = NetworksWirelessSsidsFirewallL3FirewallRules(self._task.args, meraki)
+        obj = NetworksWirelessSsidsFirewallL3FirewallRules(
+            self._task.args, meraki)
 
         state = self._task.args.get("state")
 
