@@ -499,23 +499,21 @@ def main():
 
     state = module.params.get("state")
 
-    l3out_template_object = MSOTemplate(mso, "l3out", l3out_template)
-    l3out_template_object.validate_template("l3out")
+    mso_template = MSOTemplate(mso, "l3out", l3out_template)
+    mso_template.validate_template("l3out")
 
-    tenant_id = l3out_template_object.template_summary.get("tenantId")
-    tenant_name = l3out_template_object.template_summary.get("tenantName")
+    tenant_id = mso_template.template_summary.get("tenantId")
+    tenant_name = mso_template.template_summary.get("tenantName")
 
-    l3outs = l3out_template_object.template.get("l3outTemplate", {}).get("l3outs", [])
-    object_description = "L3Out"
+    match = mso_template.get_l3out_object(uuid, name)
 
-    if state in ["query", "absent"] and l3outs == []:
-        mso.exit_json()
-    elif state == "query" and not (name or uuid):
-        mso.existing = l3outs
-    elif l3outs and (name or uuid):
-        match = l3out_template_object.get_object_by_key_value_pairs(object_description, l3outs, [KVPair("uuid", uuid) if uuid else KVPair("name", name)])
-        if match:
-            mso.existing = mso.previous = copy.deepcopy(match.details)
+    if (uuid or name) and match:
+        mso.existing = mso.previous = copy.deepcopy(insert_l3out_relation_name(match.details, mso_template))  # Query a specific object
+    elif match:
+        mso.existing = [insert_l3out_relation_name(l3out, mso_template) for l3out in match]  # Query all objects
+
+    if state != "query":
+        path = "/l3outTemplate/l3outs/{0}".format(match.index if match else "-")
 
     ops = []
 
@@ -530,7 +528,7 @@ def main():
 
         vrf_ref = None
         if vrf_dict:
-            vrf_object = l3out_template_object.get_vrf_object(vrf_dict, tenant_id, templates_objects_path)
+            vrf_object = mso_template.get_vrf_object(vrf_dict, tenant_id, templates_objects_path)
             if pim and vrf_object.details.get("l3MCast") is False:
                 mso.fail_json(
                     msg="Invalid configuration in L3Out {0}, 'PIM' cannot be enabled while using the VRF '{1}' with L3 Multicast disabled".format(
@@ -557,6 +555,7 @@ def main():
                 mso.fail_json(msg="The O(vrf) is required during the creation.")
 
             payload["vrfRef"] = vrf_ref
+            payload["vrfName"] = vrf_dict.get("name")
 
             if description:
                 payload["description"] = description
@@ -572,7 +571,8 @@ def main():
 
             outer_route_maps = dict()
             if interleak:
-                outer_route_maps["interleakRef"] = l3out_template_object.get_route_map(
+                outer_route_maps["interleakName"] = interleak
+                outer_route_maps["interleakRef"] = mso_template.get_route_map(
                     "interleak",
                     tenant_id,
                     tenant_name,
@@ -581,7 +581,8 @@ def main():
                 ).get("uuid", "")
 
             if static_route_redistribution:
-                outer_route_maps["staticRouteRedistRef"] = l3out_template_object.get_route_map(
+                outer_route_maps["staticRouteRedistName"] = static_route_redistribution
+                outer_route_maps["staticRouteRedistRef"] = mso_template.get_route_map(
                     "static_route_redistribution",
                     tenant_id,
                     tenant_name,
@@ -590,7 +591,8 @@ def main():
                 ).get("uuid", "")
 
             if connected_route_redistribution:
-                outer_route_maps["connectedRouteRedistRef"] = l3out_template_object.get_route_map(
+                outer_route_maps["connectedRouteRedistName"] = connected_route_redistribution
+                outer_route_maps["connectedRouteRedistRef"] = mso_template.get_route_map(
                     "connected_route_redistribution",
                     tenant_id,
                     tenant_name,
@@ -599,7 +601,8 @@ def main():
                 ).get("uuid", "")
 
             if attached_host_route_redistribution:
-                outer_route_maps["attachedHostRouteRedistRef"] = l3out_template_object.get_route_map(
+                outer_route_maps["attachedHostRouteRedistName"] = attached_host_route_redistribution
+                outer_route_maps["attachedHostRouteRedistRef"] = mso_template.get_route_map(
                     "attached_host_route_redistribution",
                     tenant_id,
                     tenant_name,
@@ -612,7 +615,8 @@ def main():
 
             if bgp:
                 if bgp.get("inbound_route_map"):
-                    payload["importRouteMapRef"] = l3out_template_object.get_route_map(
+                    payload["importRouteMapName"] = bgp.get("inbound_route_map")
+                    payload["importRouteMapRef"] = mso_template.get_route_map(
                         "inbound_route_map",
                         tenant_id,
                         tenant_name,
@@ -623,7 +627,8 @@ def main():
                 payload["importRouteControl"] = True if payload.get("importRouteMapRef") else False
 
                 if bgp.get("outbound_route_map"):
-                    payload["exportRouteMapRef"] = l3out_template_object.get_route_map(
+                    payload["exportRouteMapName"] = bgp.get("outbound_route_map")
+                    payload["exportRouteMapRef"] = mso_template.get_route_map(
                         "outbound_route_map",
                         tenant_id,
                         tenant_name,
@@ -632,7 +637,8 @@ def main():
                     ).get("uuid", "")
 
                 if bgp.get("route_dampening_ipv4"):
-                    payload["advancedRouteMapRefs"]["routeDampeningV4Ref"] = l3out_template_object.get_route_map(
+                    payload["advancedRouteMapRefs"]["routeDampeningV4Name"] = bgp.get("route_dampening_ipv4")
+                    payload["advancedRouteMapRefs"]["routeDampeningV4Ref"] = mso_template.get_route_map(
                         "route_dampening_ipv4",
                         tenant_id,
                         tenant_name,
@@ -641,7 +647,8 @@ def main():
                     ).get("uuid", "")
 
                 if bgp.get("route_dampening_ipv6"):
-                    payload["advancedRouteMapRefs"]["routeDampeningV6Ref"] = l3out_template_object.get_route_map(
+                    payload["advancedRouteMapRefs"]["routeDampeningV6Name"] = bgp.get("route_dampening_ipv6")
+                    payload["advancedRouteMapRefs"]["routeDampeningV6Ref"] = mso_template.get_route_map(
                         "route_dampening_ipv6",
                         tenant_id,
                         tenant_name,
@@ -684,37 +691,37 @@ def main():
                     payload["ospfAreaConfig"]["control"] = control
 
             mso.sanitize(payload)
-            ops.append(dict(op="add", path="/l3outTemplate/l3outs/-", value=payload))
+            ops.append(dict(op="add", path=path, value=payload))
         elif mso.existing:
             proposed_payload = copy.deepcopy(match.details)
-            l3out_attrs_path = "/l3outTemplate/l3outs/{0}".format(match.index)
 
             if name is not [None, ""] and mso.existing.get("name") != name:
-                ops.append(dict(op="replace", path=l3out_attrs_path + "/name", value=name))
+                ops.append(dict(op="replace", path=path + "/name", value=name))
                 proposed_payload["name"] = name
 
             if mso.existing.get("routingProtocol") != routing_protocols:
-                ops.append(dict(op="replace", path=l3out_attrs_path + "/routingProtocol", value=routing_protocols))
+                ops.append(dict(op="replace", path=path + "/routingProtocol", value=routing_protocols))
                 proposed_payload["routingProtocol"] = routing_protocols
 
             if vrf_ref is not None and mso.existing.get("vrfRef") != vrf_ref:
-                ops.append(dict(op="replace", path=l3out_attrs_path + "/vrfRef", value=vrf_ref))
+                ops.append(dict(op="replace", path=path + "/vrfRef", value=vrf_ref))
                 proposed_payload["vrfRef"] = vrf_ref
+                proposed_payload["vrfName"] = vrf_dict.get("name")
 
             if description is not None and mso.existing.get("description") != description:
-                ops.append(dict(op="replace", path=l3out_attrs_path + "/description", value=description))
+                ops.append(dict(op="replace", path=path + "/description", value=description))
                 proposed_payload["description"] = description
 
             if l3_domain is not None and mso.existing.get("l3domain") != l3_domain:
-                ops.append(dict(op="replace", path=l3out_attrs_path + "/l3domain", value=l3_domain))
+                ops.append(dict(op="replace", path=path + "/l3domain", value=l3_domain))
                 proposed_payload["l3domain"] = l3_domain
 
             if target_dscp is not None and mso.existing.get("targetDscp") != target_dscp:
-                ops.append(dict(op="replace", path=l3out_attrs_path + "/targetDscp", value=target_dscp))
+                ops.append(dict(op="replace", path=path + "/targetDscp", value=target_dscp))
                 proposed_payload["targetDscp"] = target_dscp
 
             if pim is not None and mso.existing.get("pim") != pim:
-                ops.append(dict(op="replace", path=l3out_attrs_path + "/pim", value=pim))
+                ops.append(dict(op="replace", path=path + "/pim", value=pim))
                 proposed_payload["pim"] = pim
 
             if (
@@ -724,13 +731,13 @@ def main():
                 or attached_host_route_redistribution is not None
                 or (bgp is not None and (bgp.get("route_dampening_ipv4") is not None or bgp.get("route_dampening_ipv6") is not None))
             ) and not mso.existing.get("advancedRouteMapRefs"):
-                ops.append(dict(op="add", path=l3out_attrs_path + "/advancedRouteMapRefs", value=dict()))
+                ops.append(dict(op="add", path=path + "/advancedRouteMapRefs", value=dict()))
                 proposed_payload["advancedRouteMapRefs"] = dict()
 
             outer_route_maps = dict()
 
             if interleak is not None:
-                interleak_ref = l3out_template_object.get_route_map(
+                interleak_ref = mso_template.get_route_map(
                     "interleak",
                     tenant_id,
                     tenant_name,
@@ -739,11 +746,12 @@ def main():
                 ).get("uuid", "")
 
                 if mso.existing.get("advancedRouteMapRefs", {}).get("interleakRef") != interleak_ref:
-                    ops.append(dict(op="replace", path=l3out_attrs_path + "/advancedRouteMapRefs/interleakRef", value=interleak_ref))
+                    ops.append(dict(op="replace", path=path + "/advancedRouteMapRefs/interleakRef", value=interleak_ref))
                     outer_route_maps["interleakRef"] = interleak_ref
+                    outer_route_maps["interleakName"] = interleak
 
             if static_route_redistribution is not None:
-                static_route_redistribution_ref = l3out_template_object.get_route_map(
+                static_route_redistribution_ref = mso_template.get_route_map(
                     "static_route_redistribution",
                     tenant_id,
                     tenant_name,
@@ -752,11 +760,12 @@ def main():
                 ).get("uuid", "")
 
                 if mso.existing.get("advancedRouteMapRefs", {}).get("staticRouteRedistRef") != static_route_redistribution_ref:
-                    ops.append(dict(op="replace", path=l3out_attrs_path + "/advancedRouteMapRefs/staticRouteRedistRef", value=static_route_redistribution_ref))
+                    ops.append(dict(op="replace", path=path + "/advancedRouteMapRefs/staticRouteRedistRef", value=static_route_redistribution_ref))
                     outer_route_maps["staticRouteRedistRef"] = static_route_redistribution_ref
+                    outer_route_maps["staticRouteRedistName"] = static_route_redistribution
 
             if connected_route_redistribution is not None:
-                connected_route_redistribution_ref = l3out_template_object.get_route_map(
+                connected_route_redistribution_ref = mso_template.get_route_map(
                     "connected_route_redistribution",
                     tenant_id,
                     tenant_name,
@@ -765,13 +774,12 @@ def main():
                 ).get("uuid", "")
 
                 if mso.existing.get("advancedRouteMapRefs", {}).get("connectedRouteRedistRef") != connected_route_redistribution_ref:
-                    ops.append(
-                        dict(op="replace", path=l3out_attrs_path + "/advancedRouteMapRefs/connectedRouteRedistRef", value=connected_route_redistribution_ref)
-                    )
+                    ops.append(dict(op="replace", path=path + "/advancedRouteMapRefs/connectedRouteRedistRef", value=connected_route_redistribution_ref))
                     outer_route_maps["connectedRouteRedistRef"] = connected_route_redistribution_ref
+                    outer_route_maps["connectedRouteRedistName"] = connected_route_redistribution
 
             if attached_host_route_redistribution is not None:
-                attached_host_route_redistribution_ref = l3out_template_object.get_route_map(
+                attached_host_route_redistribution_ref = mso_template.get_route_map(
                     "attached_host_route_redistribution",
                     tenant_id,
                     tenant_name,
@@ -783,15 +791,16 @@ def main():
                     ops.append(
                         dict(
                             op="replace",
-                            path=l3out_attrs_path + "/advancedRouteMapRefs/attachedHostRouteRedistRef",
+                            path=path + "/advancedRouteMapRefs/attachedHostRouteRedistRef",
                             value=attached_host_route_redistribution_ref,
                         )
                     )
                     outer_route_maps["attachedHostRouteRedistRef"] = attached_host_route_redistribution_ref
+                    outer_route_maps["attachedHostRouteRedistName"] = attached_host_route_redistribution
 
             if bgp and bgp_state != "disabled":
                 if bgp.get("inbound_route_map") is not None:
-                    inbound_route_map_ref = l3out_template_object.get_route_map(
+                    inbound_route_map_ref = mso_template.get_route_map(
                         "inbound_route_map",
                         tenant_id,
                         tenant_name,
@@ -800,14 +809,15 @@ def main():
                     ).get("uuid", "")
 
                     if mso.existing.get("importRouteMapRef") != inbound_route_map_ref:
-                        ops.append(dict(op="replace", path=l3out_attrs_path + "/importRouteMapRef", value=inbound_route_map_ref))
-                        ops.append(dict(op="replace", path=l3out_attrs_path + "/importRouteControl", value=True if inbound_route_map_ref else False))
+                        ops.append(dict(op="replace", path=path + "/importRouteMapRef", value=inbound_route_map_ref))
+                        ops.append(dict(op="replace", path=path + "/importRouteControl", value=True if inbound_route_map_ref else False))
 
                         proposed_payload["importRouteMapRef"] = inbound_route_map_ref
+                        proposed_payload["importRouteMapName"] = bgp.get("inbound_route_map")
                         proposed_payload["importRouteControl"] = True if inbound_route_map_ref else False
 
                 if bgp.get("outbound_route_map") is not None:
-                    outbound_route_map_ref = l3out_template_object.get_route_map(
+                    outbound_route_map_ref = mso_template.get_route_map(
                         "outbound_route_map",
                         tenant_id,
                         tenant_name,
@@ -816,11 +826,12 @@ def main():
                     ).get("uuid", "")
 
                     if mso.existing.get("exportRouteMapRef") != outbound_route_map_ref:
-                        ops.append(dict(op="replace", path=l3out_attrs_path + "/exportRouteMapRef", value=outbound_route_map_ref))
+                        ops.append(dict(op="replace", path=path + "/exportRouteMapRef", value=outbound_route_map_ref))
                         proposed_payload["exportRouteMapRef"] = outbound_route_map_ref
+                        proposed_payload["exportRouteMapName"] = bgp.get("outbound_route_map")
 
                 if bgp.get("route_dampening_ipv4") is not None:
-                    route_dampening_ipv4_ref = l3out_template_object.get_route_map(
+                    route_dampening_ipv4_ref = mso_template.get_route_map(
                         "route_dampening_ipv4",
                         tenant_id,
                         tenant_name,
@@ -829,11 +840,12 @@ def main():
                     ).get("uuid", "")
 
                     if mso.existing.get("advancedRouteMapRefs", {}).get("routeDampeningV4Ref") != route_dampening_ipv4_ref:
-                        ops.append(dict(op="replace", path=l3out_attrs_path + "/advancedRouteMapRefs/routeDampeningV4Ref", value=route_dampening_ipv4_ref))
+                        ops.append(dict(op="replace", path=path + "/advancedRouteMapRefs/routeDampeningV4Ref", value=route_dampening_ipv4_ref))
                         outer_route_maps["routeDampeningV4Ref"] = route_dampening_ipv4_ref
+                        outer_route_maps["routeDampeningV4Name"] = bgp.get("route_dampening_ipv4")
 
                 if bgp.get("route_dampening_ipv6") is not None:
-                    route_dampening_ipv6_ref = l3out_template_object.get_route_map(
+                    route_dampening_ipv6_ref = mso_template.get_route_map(
                         "route_dampening_ipv6",
                         tenant_id,
                         tenant_name,
@@ -842,22 +854,23 @@ def main():
                     ).get("uuid", "")
 
                     if mso.existing.get("advancedRouteMapRefs", {}).get("routeDampeningV6Ref") != route_dampening_ipv6_ref:
-                        ops.append(dict(op="replace", path=l3out_attrs_path + "/advancedRouteMapRefs/routeDampeningV6Ref", value=route_dampening_ipv6_ref))
+                        ops.append(dict(op="replace", path=path + "/advancedRouteMapRefs/routeDampeningV6Ref", value=route_dampening_ipv6_ref))
                         outer_route_maps["routeDampeningV6Ref"] = route_dampening_ipv6_ref
+                        outer_route_maps["routeDampeningV6Name"] = bgp.get("route_dampening_ipv6")
 
             elif bgp_state == "disabled":
-                ops.append(dict(op="replace", path=l3out_attrs_path + "/importRouteMapRef", value=""))
-                ops.append(dict(op="replace", path=l3out_attrs_path + "/importRouteControl", value=False))
+                ops.append(dict(op="replace", path=path + "/importRouteMapRef", value=""))
+                ops.append(dict(op="replace", path=path + "/importRouteControl", value=False))
                 proposed_payload.pop("importRouteMapRef", None)
                 proposed_payload["importRouteControl"] = False
 
-                ops.append(dict(op="replace", path=l3out_attrs_path + "/exportRouteMapRef", value=""))
+                ops.append(dict(op="replace", path=path + "/exportRouteMapRef", value=""))
                 proposed_payload.pop("exportRouteMapRef", None)
 
-                ops.append(dict(op="replace", path=l3out_attrs_path + "/advancedRouteMapRefs/routeDampeningV6Ref", value=""))
+                ops.append(dict(op="replace", path=path + "/advancedRouteMapRefs/routeDampeningV6Ref", value=""))
                 proposed_payload.get("advancedRouteMapRefs", {}).pop("routeDampeningV6Ref", None)
 
-                ops.append(dict(op="replace", path=l3out_attrs_path + "/advancedRouteMapRefs/routeDampeningV4Ref", value=""))
+                ops.append(dict(op="replace", path=path + "/advancedRouteMapRefs/routeDampeningV4Ref", value=""))
                 proposed_payload.get("advancedRouteMapRefs", {}).pop("routeDampeningV4Ref", None)
 
             if outer_route_maps:
@@ -869,42 +882,42 @@ def main():
                 originate_default_route_always = ospf.get("originate_default_route_always")
 
                 if originate_default_route is not None and originate_default_route == "" and mso.existing.get("defaultRouteLeak"):
-                    ops.append(dict(op="remove", path=l3out_attrs_path + "/defaultRouteLeak"))
+                    ops.append(dict(op="remove", path=path + "/defaultRouteLeak"))
                     proposed_payload.pop("defaultRouteLeak", None)
 
                 elif (originate_default_route is not None and originate_default_route != "") or (originate_default_route_always is not None):
                     if not mso.existing.get("defaultRouteLeak"):
-                        ops.append(dict(op="replace", path=l3out_attrs_path + "/defaultRouteLeak", value=dict()))
+                        ops.append(dict(op="replace", path=path + "/defaultRouteLeak", value=dict()))
                         proposed_payload["defaultRouteLeak"] = dict()
 
                     if originate_default_route != mso.existing.get("defaultRouteLeak", {}).get("originateDefaultRoute"):
                         ops.append(
                             dict(
                                 op="replace",
-                                path=l3out_attrs_path + "/defaultRouteLeak/originateDefaultRoute",
+                                path=path + "/defaultRouteLeak/originateDefaultRoute",
                                 value=originate_default_route,
                             )
                         )
                         proposed_payload["defaultRouteLeak"]["originateDefaultRoute"] = originate_default_route
 
                     if originate_default_route_always is not None and originate_default_route_always != mso.existing.get("defaultRouteLeak", {}).get("always"):
-                        ops.append(dict(op="replace", path=l3out_attrs_path + "/defaultRouteLeak/always", value=originate_default_route_always))
+                        ops.append(dict(op="replace", path=path + "/defaultRouteLeak/always", value=originate_default_route_always))
                         proposed_payload["defaultRouteLeak"]["always"] = originate_default_route_always
 
                 if not mso.existing.get("ospfAreaConfig"):
-                    ops.append(dict(op="replace", path=l3out_attrs_path + "/ospfAreaConfig", value=dict()))
+                    ops.append(dict(op="replace", path=path + "/ospfAreaConfig", value=dict()))
                     proposed_payload["ospfAreaConfig"] = dict()
 
                 if ospf.get("cost") is not None and ospf.get("cost") != mso.existing.get("ospfAreaConfig", {}).get("cost"):
-                    ops.append(dict(op="replace", path=l3out_attrs_path + "/ospfAreaConfig/cost", value=ospf.get("cost")))
+                    ops.append(dict(op="replace", path=path + "/ospfAreaConfig/cost", value=ospf.get("cost")))
                     proposed_payload["ospfAreaConfig"]["cost"] = ospf.get("cost")
 
                 if ospf.get("area_id") is not None and ospf.get("area_id") != mso.existing.get("ospfAreaConfig", {}).get("id"):
-                    ops.append(dict(op="replace", path=l3out_attrs_path + "/ospfAreaConfig/id", value=ospf.get("area_id")))
+                    ops.append(dict(op="replace", path=path + "/ospfAreaConfig/id", value=ospf.get("area_id")))
                     proposed_payload["ospfAreaConfig"]["id"] = ospf.get("area_id")
 
                 if ospf.get("area_type") is not None and ospf.get("area_type") != mso.existing.get("ospfAreaConfig", {}).get("areaType"):
-                    ops.append(dict(op="replace", path=l3out_attrs_path + "/ospfAreaConfig/areaType", value=ospf.get("area_type")))
+                    ops.append(dict(op="replace", path=path + "/ospfAreaConfig/areaType", value=ospf.get("area_type")))
                     proposed_payload["ospfAreaConfig"]["areaType"] = ospf.get("area_type")
 
                 redistribute = ospf.get("send_redistributed_lsas")
@@ -914,26 +927,26 @@ def main():
                 if (redistribute is not None or originate is not None or suppress_fa is not None) and not mso.existing.get("ospfAreaConfig", {}).get(
                     "control"
                 ):
-                    ops.append(dict(op="replace", path=l3out_attrs_path + "/ospfAreaConfig/control", value=dict()))
+                    ops.append(dict(op="replace", path=path + "/ospfAreaConfig/control", value=dict()))
                     proposed_payload["ospfAreaConfig"]["control"] = dict()
 
                 if redistribute is not None and redistribute != mso.existing.get("ospfAreaConfig", {}).get("control", {}).get("redistribute"):
-                    ops.append(dict(op="replace", path=l3out_attrs_path + "/ospfAreaConfig/control/redistribute", value=redistribute))
+                    ops.append(dict(op="replace", path=path + "/ospfAreaConfig/control/redistribute", value=redistribute))
                     proposed_payload["ospfAreaConfig"]["control"]["redistribute"] = redistribute
 
                 if originate is not None and originate != mso.existing.get("ospfAreaConfig", {}).get("control", {}).get("originate"):
-                    ops.append(dict(op="replace", path=l3out_attrs_path + "/ospfAreaConfig/control/originate", value=originate))
+                    ops.append(dict(op="replace", path=path + "/ospfAreaConfig/control/originate", value=originate))
                     proposed_payload["ospfAreaConfig"]["control"]["originate"] = originate
 
                 if suppress_fa is not None and suppress_fa != mso.existing.get("ospfAreaConfig", {}).get("control", {}).get("suppressFA"):
-                    ops.append(dict(op="replace", path=l3out_attrs_path + "/ospfAreaConfig/control/suppressFA", value=suppress_fa))
+                    ops.append(dict(op="replace", path=path + "/ospfAreaConfig/control/suppressFA", value=suppress_fa))
                     proposed_payload["ospfAreaConfig"]["control"]["suppressFA"] = suppress_fa
 
             elif ospf_state == "disabled":
-                ops.append(dict(op="remove", path=l3out_attrs_path + "/ospfAreaConfig"))
+                ops.append(dict(op="remove", path=path + "/ospfAreaConfig"))
                 proposed_payload.pop("ospfAreaConfig", None)
 
-                ops.append(dict(op="remove", path=l3out_attrs_path + "/defaultRouteLeak"))
+                ops.append(dict(op="remove", path=path + "/defaultRouteLeak"))
                 proposed_payload.pop("defaultRouteLeak", None)
 
             mso.sanitize(proposed_payload, collate=True)
@@ -943,18 +956,155 @@ def main():
             ops.append(dict(op="remove", path="/l3outTemplate/l3outs/{0}".format(match.index)))
 
     if not module.check_mode and ops:
-        response_object = mso.request(l3out_template_object.template_path, method="PATCH", data=ops)
-        l3outs = response_object.get("l3outTemplate", {}).get("l3outs", [])
-        match = l3out_template_object.get_object_by_key_value_pairs(object_description, l3outs, [KVPair("uuid", uuid) if uuid else KVPair("name", name)])
+        response_object = mso.request(mso_template.template_path, method="PATCH", data=ops)
+
+        mso_template.template = response_object
+        match = mso_template.get_l3out_object(uuid, name)
+
         if match:
-            mso.existing = match.details  # When the state is present
+            mso.existing = insert_l3out_relation_name(match.details, mso_template)  # When the state is present
         else:
             mso.existing = {}  # When the state is absent
     elif module.check_mode and state != "query":  # When the state is present/absent with check mode
-        mso.existing = mso.proposed if state == "present" else {}
+        mso.existing = insert_l3out_relation_name(mso.proposed, mso_template, module.check_mode) if state == "present" else {}
 
     mso.exit_json()
 
 
+def insert_l3out_relation_name(l3out_object, mso_template, check_mode=False):
+    l3out_object["vrfName"] = mso_template.get_template_object_name_by_uuid("vrf", l3out_object.get("vrfRef"))
+
+    if not check_mode:
+        l3out_relations = mso_template.mso.request("{0}/relations".format(mso_template.template_path), "GET")
+        route_map_policies = l3out_relations.get("relations", {}).get("identities", {}).get("routeMapPolicies", [])
+
+    if "exportRouteMapRef" in l3out_object:
+        if check_mode:
+            l3out_object["exportRouteMapName"] = mso_template.get_template_object_name_by_uuid("routeMap", l3out_object["exportRouteMapRef"])
+        else:
+            l3out_object["exportRouteMapName"] = (
+                mso_template.get_object_by_key_value_pairs(
+                    "Route Map",
+                    route_map_policies,
+                    [KVPair("ref", l3out_object["exportRouteMapRef"])],
+                    True,
+                ).details
+                or {}
+            ).get("displayName")
+
+    if "importRouteMapRef" in l3out_object:
+        if check_mode:
+            l3out_object["importRouteMapName"] = mso_template.get_template_object_name_by_uuid("routeMap", l3out_object["importRouteMapRef"])
+        else:
+            l3out_object["importRouteMapName"] = (
+                mso_template.get_object_by_key_value_pairs(
+                    "Route Map",
+                    route_map_policies,
+                    [KVPair("ref", l3out_object["importRouteMapRef"])],
+                    True,
+                ).details
+                or {}
+            ).get("displayName")
+
+    advanced_route_maps = l3out_object.get("advancedRouteMapRefs")
+    if advanced_route_maps is not None:
+        if "attachedHostRouteRedistRef" in advanced_route_maps:
+            if check_mode:
+                l3out_object["advancedRouteMapRefs"]["attachedHostRouteRedistName"] = mso_template.get_template_object_name_by_uuid(
+                    "routeMap", advanced_route_maps["attachedHostRouteRedistRef"]
+                )
+            else:
+                l3out_object["advancedRouteMapRefs"]["attachedHostRouteRedistName"] = (
+                    mso_template.get_object_by_key_value_pairs(
+                        "Route Map",
+                        route_map_policies,
+                        [KVPair("ref", advanced_route_maps["attachedHostRouteRedistRef"])],
+                        True,
+                    ).details
+                    or {}
+                ).get("displayName")
+
+        if "connectedRouteRedistRef" in advanced_route_maps:
+            if check_mode:
+                l3out_object["advancedRouteMapRefs"]["connectedRouteRedistName"] = mso_template.get_template_object_name_by_uuid(
+                    "routeMap", advanced_route_maps["connectedRouteRedistRef"]
+                )
+            else:
+                l3out_object["advancedRouteMapRefs"]["connectedRouteRedistName"] = (
+                    mso_template.get_object_by_key_value_pairs(
+                        "Route Map",
+                        route_map_policies,
+                        [KVPair("ref", advanced_route_maps["connectedRouteRedistRef"])],
+                        True,
+                    ).details
+                    or {}
+                ).get("displayName")
+
+        if "interleakRef" in advanced_route_maps:
+            if check_mode:
+                l3out_object["advancedRouteMapRefs"]["interleakName"] = mso_template.get_template_object_name_by_uuid(
+                    "routeMap", advanced_route_maps["interleakRef"]
+                )
+            else:
+                l3out_object["advancedRouteMapRefs"]["interleakName"] = (
+                    mso_template.get_object_by_key_value_pairs(
+                        "Route Map",
+                        route_map_policies,
+                        [KVPair("ref", advanced_route_maps["interleakRef"])],
+                        True,
+                    ).details
+                    or {}
+                ).get("displayName")
+
+        if "routeDampeningV4Ref" in advanced_route_maps:
+            if check_mode:
+                l3out_object["advancedRouteMapRefs"]["routeDampeningV4Name"] = mso_template.get_template_object_name_by_uuid(
+                    "routeMap", advanced_route_maps["routeDampeningV4Ref"]
+                )
+            else:
+                l3out_object["advancedRouteMapRefs"]["routeDampeningV4Name"] = (
+                    mso_template.get_object_by_key_value_pairs(
+                        "Route Map",
+                        route_map_policies,
+                        [KVPair("ref", advanced_route_maps["routeDampeningV4Ref"])],
+                        True,
+                    ).details
+                    or {}
+                ).get("displayName")
+
+        if "routeDampeningV6Ref" in advanced_route_maps:
+            if check_mode:
+                l3out_object["advancedRouteMapRefs"]["routeDampeningV6Name"] = mso_template.get_template_object_name_by_uuid(
+                    "routeMap", advanced_route_maps["routeDampeningV6Ref"]
+                )
+            else:
+                l3out_object["advancedRouteMapRefs"]["routeDampeningV6Name"] = (
+                    mso_template.get_object_by_key_value_pairs(
+                        "Route Map",
+                        route_map_policies,
+                        [KVPair("ref", advanced_route_maps["routeDampeningV6Ref"])],
+                        True,
+                    ).details
+                    or {}
+                ).get("displayName")
+
+        if "staticRouteRedistRef" in advanced_route_maps:
+            if check_mode:
+                l3out_object["advancedRouteMapRefs"]["staticRouteRedistName"] = mso_template.get_template_object_name_by_uuid(
+                    "routeMap", advanced_route_maps["staticRouteRedistRef"]
+                )
+            else:
+                l3out_object["advancedRouteMapRefs"]["staticRouteRedistName"] = (
+                    mso_template.get_object_by_key_value_pairs(
+                        "Route Map",
+                        route_map_policies,
+                        [KVPair("ref", advanced_route_maps["staticRouteRedistRef"])],
+                        True,
+                    ).details
+                    or {}
+                ).get("displayName")
+    return l3out_object
+
+
 if __name__ == "__main__":
     main()
