@@ -1,31 +1,17 @@
 #!/usr/bin/python
-# This file is part of Ansible
-#
-# Ansible is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# Ansible is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Ansible.  If not, see <http://www.gnu.org/licenses/>.
+# -*- coding: utf-8 -*-
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+# Copyright: Contributors to the Ansible project
+# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-
-DOCUMENTATION = '''
+DOCUMENTATION = r"""
 ---
 module: s3_sync
 version_added: 1.0.0
 short_description: Efficiently upload multiple files to S3
 description:
-     - The S3 module is great, but it is very slow for a large volume of files- even a dozen will be noticeable. In addition to speed, it handles globbing,
-       inclusions/exclusions, mime types, expiration mapping, recursion, cache control and smart directory mapping.
+- The S3 module is great, but it is very slow for a large volume of files- even a dozen will be noticeable. In addition to speed, it handles globbing,
+  inclusions/exclusions, mime types, expiration mapping, recursion, cache control and smart directory mapping.
 options:
   mode:
     description:
@@ -53,6 +39,7 @@ options:
     - In addition to file path, prepend s3 path with this prefix. Module will add slash at end of prefix if necessary.
     required: false
     type: str
+    default: ''
   file_root:
     description:
     - File/directory path for synchronization. This is a local path.
@@ -102,6 +89,7 @@ options:
     - Directives are separated by commas.
     required: false
     type: str
+    default: ''
   storage_class:
     description:
     - Storage class to be associated to each object added to the S3 bucket.
@@ -122,21 +110,18 @@ options:
     description:
     - Remove remote files that exist in bucket but are not present in the file root.
     required: false
-    default: no
+    default: false
     type: bool
-  retries:
-    description:
-      - The I(retries) option does nothing and will be removed after 2022-06-01
-    type: str
 
-author: Ted Timmons (@tedder)
+author:
+- Ted Timmons (@tedder)
 extends_documentation_fragment:
-- amazon.aws.aws
-- amazon.aws.ec2
+- amazon.aws.common.modules
+- amazon.aws.region.modules
+- amazon.aws.boto3
+"""
 
-'''
-
-EXAMPLES = '''
+EXAMPLES = r"""
 - name: basic upload
   community.aws.s3_sync:
     bucket: tedder
@@ -167,9 +152,9 @@ EXAMPLES = '''
     storage_class: "GLACIER"
     include: "*"
     exclude: "*.txt,.*"
-'''
+"""
 
-RETURN = '''
+RETURN = r"""
 filelist_initial:
   description: file listing (dicts) from initial globbing
   returned: always
@@ -242,88 +227,32 @@ uploads:
                 "whytime": "1477931637 / 1477931489"
            }]
 
-'''
+"""
 
 import datetime
 import fnmatch
-import hashlib
 import mimetypes
 import os
 import stat as osstat  # os.stat constants
 
 try:
     from dateutil import tz
+
     HAS_DATEUTIL = True
 except ImportError:
     HAS_DATEUTIL = False
 
 try:
     import botocore
-    from boto3.s3.transfer import TransferConfig
-    DEFAULT_CHUNK_SIZE = TransferConfig().multipart_chunksize
 except ImportError:
-    DEFAULT_CHUNK_SIZE = 5 * 1024 * 1024
     pass  # Handled by AnsibleAWSModule
 
 from ansible.module_utils._text import to_text
 
-# import module snippets
-from ansible_collections.amazon.aws.plugins.module_utils.core import AnsibleAWSModule
-from ansible_collections.amazon.aws.plugins.module_utils.core import is_boto3_error_code
+from ansible_collections.amazon.aws.plugins.module_utils.botocore import is_boto3_error_code
 
-
-# the following function, calculate_multipart_etag, is from tlastowka
-# on github and is used under its (compatible) GPL license. So this
-# license applies to the following function.
-# source: https://github.com/tlastowka/calculate_multipart_etag/blob/master/calculate_multipart_etag.py
-#
-# calculate_multipart_etag  Copyright (C) 2015
-#      Tony Lastowka <tlastowka at gmail dot com>
-#      https://github.com/tlastowka
-#
-#
-# calculate_multipart_etag is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# calculate_multipart_etag is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with calculate_multipart_etag.  If not, see <http://www.gnu.org/licenses/>.
-def calculate_multipart_etag(source_path, chunk_size=DEFAULT_CHUNK_SIZE):
-    """
-    calculates a multipart upload etag for amazon s3
-
-    Arguments:
-
-    source_path -- The file to calculate the etag for
-    chunk_size -- The chunk size to calculate for.
-    """
-
-    md5s = []
-
-    with open(source_path, 'rb') as fp:
-        while True:
-
-            data = fp.read(chunk_size)
-
-            if not data:
-                break
-            md5s.append(hashlib.md5(data))
-
-    if len(md5s) == 1:
-        new_etag = '"{0}"'.format(md5s[0].hexdigest())
-    else:  # > 1
-        digests = b"".join(m.digest() for m in md5s)
-
-        new_md5 = hashlib.md5(digests)
-        new_etag = '"{0}-{1}"'.format(new_md5.hexdigest(), len(md5s))
-
-    return new_etag
+from ansible_collections.community.aws.plugins.module_utils.etag import calculate_multipart_etag
+from ansible_collections.community.aws.plugins.module_utils.modules import AnsibleCommunityAWSModule as AnsibleAWSModule
 
 
 def gather_files(fileroot, include=None, exclude=None):
@@ -332,25 +261,27 @@ def gather_files(fileroot, include=None, exclude=None):
     if os.path.isfile(fileroot):
         fullpath = fileroot
         fstat = os.stat(fullpath)
-        path_array = fileroot.split('/')
+        path_array = fileroot.split("/")
         chopped_path = path_array[-1]
         f_size = fstat[osstat.ST_SIZE]
         f_modified_epoch = fstat[osstat.ST_MTIME]
-        ret.append({
-            'fullpath': fullpath,
-            'chopped_path': chopped_path,
-            'modified_epoch': f_modified_epoch,
-            'bytes': f_size,
-        })
+        ret.append(
+            {
+                "fullpath": fullpath,
+                "chopped_path": chopped_path,
+                "modified_epoch": f_modified_epoch,
+                "bytes": f_size,
+            }
+        )
 
     else:
-        for (dirpath, dirnames, filenames) in os.walk(fileroot):
+        for dirpath, dirnames, filenames in os.walk(fileroot):
             for fn in filenames:
                 fullpath = os.path.join(dirpath, fn)
                 # include/exclude
                 if include:
                     found = False
-                    for x in include.split(','):
+                    for x in include.split(","):
                         if fnmatch.fnmatch(fn, x):
                             found = True
                     if not found:
@@ -359,7 +290,7 @@ def gather_files(fileroot, include=None, exclude=None):
 
                 if exclude:
                     found = False
-                    for x in exclude.split(','):
+                    for x in exclude.split(","):
                         if fnmatch.fnmatch(fn, x):
                             found = True
                     if found:
@@ -370,36 +301,38 @@ def gather_files(fileroot, include=None, exclude=None):
                 fstat = os.stat(fullpath)
                 f_size = fstat[osstat.ST_SIZE]
                 f_modified_epoch = fstat[osstat.ST_MTIME]
-                ret.append({
-                    'fullpath': fullpath,
-                    'chopped_path': chopped_path,
-                    'modified_epoch': f_modified_epoch,
-                    'bytes': f_size,
-                })
+                ret.append(
+                    {
+                        "fullpath": fullpath,
+                        "chopped_path": chopped_path,
+                        "modified_epoch": f_modified_epoch,
+                        "bytes": f_size,
+                    }
+                )
             # dirpath = path *to* the directory
             # dirnames = subdirs *in* our directory
             # filenames
     return ret
 
 
-def calculate_s3_path(filelist, key_prefix=''):
+def calculate_s3_path(filelist, key_prefix=""):
     ret = []
     for fileentry in filelist:
         # don't modify the input dict
         retentry = fileentry.copy()
-        retentry['s3_path'] = os.path.join(key_prefix, fileentry['chopped_path'])
+        retentry["s3_path"] = os.path.join(key_prefix, fileentry["chopped_path"])
         ret.append(retentry)
     return ret
 
 
-def calculate_local_etag(filelist, key_prefix=''):
-    '''Really, "calculate md5", but since AWS uses their own format, we'll just call
-       it a "local etag". TODO optimization: only calculate if remote key exists.'''
+def calculate_local_etag(filelist, key_prefix=""):
+    """Really, "calculate md5", but since AWS uses their own format, we'll just call
+    it a "local etag". TODO optimization: only calculate if remote key exists."""
     ret = []
     for fileentry in filelist:
         # don't modify the input dict
         retentry = fileentry.copy()
-        retentry['local_etag'] = calculate_multipart_etag(fileentry['fullpath'])
+        retentry["local_etag"] = calculate_multipart_etag(fileentry["fullpath"])
         ret.append(retentry)
     return ret
 
@@ -408,20 +341,20 @@ def determine_mimetypes(filelist, override_map):
     ret = []
     for fileentry in filelist:
         retentry = fileentry.copy()
-        localfile = fileentry['fullpath']
+        localfile = fileentry["fullpath"]
 
         # reminder: file extension is '.txt', not 'txt'.
         file_extension = os.path.splitext(localfile)[1]
         if override_map and override_map.get(file_extension):
             # override? use it.
-            retentry['mime_type'] = override_map[file_extension]
+            retentry["mime_type"] = override_map[file_extension]
         else:
             # else sniff it
-            retentry['mime_type'], retentry['encoding'] = mimetypes.guess_type(localfile, strict=False)
+            retentry["mime_type"], retentry["encoding"] = mimetypes.guess_type(localfile, strict=False)
 
         # might be None or '' from one of the above. Not a great type but better than nothing.
-        if not retentry['mime_type']:
-            retentry['mime_type'] = 'application/octet-stream'
+        if not retentry["mime_type"]:
+            retentry["mime_type"] = "application/octet-stream"
 
         ret.append(retentry)
 
@@ -433,10 +366,10 @@ def head_s3(s3, bucket, s3keys):
     for entry in s3keys:
         retentry = entry.copy()
         try:
-            retentry['s3_head'] = s3.head_object(Bucket=bucket, Key=entry['s3_path'])
+            retentry["s3_head"] = s3.head_object(Bucket=bucket, Key=entry["s3_path"])
         # 404 (Missing) - File doesn't exist, we'll need to upload
         # 403 (Denied) - Sometimes we can write but not read, assume we'll need to upload
-        except is_boto3_error_code(['404', '403']):
+        except is_boto3_error_code(["404", "403"]):
             pass
         retkeys.append(retentry)
     return retkeys
@@ -446,107 +379,127 @@ def filter_list(s3, bucket, s3filelist, strategy):
     keeplist = list(s3filelist)
 
     for e in keeplist:
-        e['_strategy'] = strategy
+        e["_strategy"] = strategy
 
     # init/fetch info from S3 if we're going to use it for comparisons
-    if not strategy == 'force':
+    if not strategy == "force":
         keeplist = head_s3(s3, bucket, s3filelist)
 
     # now actually run the strategies
-    if strategy == 'checksum':
+    if strategy == "checksum":
         for entry in keeplist:
-            if entry.get('s3_head'):
+            if entry.get("s3_head"):
                 # since we have a remote s3 object, compare the values.
-                if entry['s3_head']['ETag'] == entry['local_etag']:
+                if entry["s3_head"]["ETag"] == entry["local_etag"]:
                     # files match, so remove the entry
-                    entry['skip_flag'] = True
+                    entry["skip_flag"] = True
                 else:
                     # file etags don't match, keep the entry.
                     pass
             else:  # we don't have an etag, so we'll keep it.
                 pass
-    elif strategy == 'date_size':
+    elif strategy == "date_size":
         for entry in keeplist:
-            if entry.get('s3_head'):
+            if entry.get("s3_head"):
                 # fstat = entry['stat']
-                local_modified_epoch = entry['modified_epoch']
-                local_size = entry['bytes']
+                local_modified_epoch = entry["modified_epoch"]
+                local_size = entry["bytes"]
 
                 # py2's datetime doesn't have a timestamp() field, so we have to revert to something more awkward.
                 # remote_modified_epoch = entry['s3_head']['LastModified'].timestamp()
-                remote_modified_datetime = entry['s3_head']['LastModified']
-                delta = (remote_modified_datetime - datetime.datetime(1970, 1, 1, tzinfo=tz.tzutc()))
+                remote_modified_datetime = entry["s3_head"]["LastModified"]
+                delta = remote_modified_datetime - datetime.datetime(1970, 1, 1, tzinfo=tz.tzutc())
                 remote_modified_epoch = delta.seconds + (delta.days * 86400)
 
-                remote_size = entry['s3_head']['ContentLength']
+                remote_size = entry["s3_head"]["ContentLength"]
 
-                entry['whytime'] = '{0} / {1}'.format(local_modified_epoch, remote_modified_epoch)
-                entry['whysize'] = '{0} / {1}'.format(local_size, remote_size)
+                entry["whytime"] = f"{local_modified_epoch} / {remote_modified_epoch}"
+                entry["whysize"] = f"{local_size} / {remote_size}"
 
                 if local_modified_epoch <= remote_modified_epoch and local_size == remote_size:
-                    entry['skip_flag'] = True
+                    entry["skip_flag"] = True
             else:
-                entry['why'] = "no s3_head"
+                entry["why"] = "no s3_head"
     # else: probably 'force'. Basically we don't skip with any with other strategies.
     else:
         pass
 
     # prune 'please skip' entries, if any.
-    return [x for x in keeplist if not x.get('skip_flag')]
+    return [x for x in keeplist if not x.get("skip_flag")]
 
 
 def upload_files(s3, bucket, filelist, params):
     ret = []
     for entry in filelist:
-        args = {
-            'ContentType': entry['mime_type']
-        }
-        if params.get('permission'):
-            args['ACL'] = params['permission']
-        if params.get('cache_control'):
-            args['CacheControl'] = params['cache_control']
-        if params.get('storage_class'):
-            args['StorageClass'] = params['storage_class']
+        args = {"ContentType": entry["mime_type"]}
+        if params.get("permission"):
+            args["ACL"] = params["permission"]
+        if params.get("cache_control"):
+            args["CacheControl"] = params["cache_control"]
+        if params.get("storage_class"):
+            args["StorageClass"] = params["storage_class"]
         # if this fails exception is caught in main()
-        s3.upload_file(entry['fullpath'], bucket, entry['s3_path'], ExtraArgs=args, Callback=None, Config=None)
+        s3.upload_file(entry["fullpath"], bucket, entry["s3_path"], ExtraArgs=args, Callback=None, Config=None)
         ret.append(entry)
     return ret
 
 
 def remove_files(s3, sourcelist, params):
-    bucket = params.get('bucket')
-    key_prefix = params.get('key_prefix')
-    paginator = s3.get_paginator('list_objects_v2')
-    current_keys = set(x['Key'] for x in paginator.paginate(Bucket=bucket, Prefix=key_prefix).build_full_result().get('Contents', []))
-    keep_keys = set(to_text(source_file['s3_path']) for source_file in sourcelist)
+    bucket = params.get("bucket")
+    key_prefix = params.get("key_prefix")
+    paginator = s3.get_paginator("list_objects_v2")
+    current_keys = set(
+        x["Key"] for x in paginator.paginate(Bucket=bucket, Prefix=key_prefix).build_full_result().get("Contents", [])
+    )
+    keep_keys = set(to_text(source_file["s3_path"]) for source_file in sourcelist)
     delete_keys = list(current_keys - keep_keys)
 
     # can delete 1000 objects at a time
-    groups_of_keys = [delete_keys[i:i + 1000] for i in range(0, len(delete_keys), 1000)]
+    groups_of_keys = [delete_keys[i:i + 1000] for i in range(0, len(delete_keys), 1000)]  # fmt:skip
     for keys in groups_of_keys:
-        s3.delete_objects(Bucket=bucket, Delete={'Objects': [{'Key': key} for key in keys]})
+        s3.delete_objects(Bucket=bucket, Delete={"Objects": [{"Key": key} for key in keys]})
 
     return delete_keys
 
 
 def main():
     argument_spec = dict(
-        mode=dict(choices=['push'], default='push'),
-        file_change_strategy=dict(choices=['force', 'date_size', 'checksum'], default='date_size'),
+        mode=dict(choices=["push"], default="push"),
+        file_change_strategy=dict(choices=["force", "date_size", "checksum"], default="date_size"),
         bucket=dict(required=True),
-        key_prefix=dict(required=False, default='', no_log=False),
-        file_root=dict(required=True, type='path'),
-        permission=dict(required=False, choices=['private', 'public-read', 'public-read-write', 'authenticated-read',
-                                                 'aws-exec-read', 'bucket-owner-read', 'bucket-owner-full-control']),
-        retries=dict(required=False, removed_at_date='2022-06-01', removed_from_collection='community.aws'),
-        mime_map=dict(required=False, type='dict'),
+        key_prefix=dict(required=False, default="", no_log=False),
+        file_root=dict(required=True, type="path"),
+        permission=dict(
+            required=False,
+            choices=[
+                "private",
+                "public-read",
+                "public-read-write",
+                "authenticated-read",
+                "aws-exec-read",
+                "bucket-owner-read",
+                "bucket-owner-full-control",
+            ],
+        ),
+        mime_map=dict(required=False, type="dict"),
         exclude=dict(required=False, default=".*"),
         include=dict(required=False, default="*"),
-        cache_control=dict(required=False, default=''),
-        delete=dict(required=False, type='bool', default=False),
-        storage_class=dict(required=False, default='STANDARD',
-                           choices=['STANDARD', 'REDUCED_REDUNDANCY', 'STANDARD_IA', 'ONEZONE_IA',
-                                    'INTELLIGENT_TIERING', 'GLACIER', 'DEEP_ARCHIVE', 'OUTPOSTS']),
+        cache_control=dict(required=False, default=""),
+        delete=dict(required=False, type="bool", default=False),
+        storage_class=dict(
+            required=False,
+            default="STANDARD",
+            choices=[
+                "STANDARD",
+                "REDUCED_REDUNDANCY",
+                "STANDARD_IA",
+                "ONEZONE_IA",
+                "INTELLIGENT_TIERING",
+                "GLACIER",
+                "DEEP_ARCHIVE",
+                "OUTPOSTS",
+            ],
+        ),
         # future options: encoding, metadata, retries
     )
 
@@ -555,31 +508,43 @@ def main():
     )
 
     if not HAS_DATEUTIL:
-        module.fail_json(msg='dateutil required for this module')
+        module.fail_json(msg="dateutil required for this module")
 
     result = {}
-    mode = module.params['mode']
+    mode = module.params["mode"]
 
     try:
-        s3 = module.client('s3')
+        s3 = module.client("s3")
     except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
-        module.fail_json_aws(e, msg='Failed to connect to AWS')
+        module.fail_json_aws(e, msg="Failed to connect to AWS")
 
-    if mode == 'push':
+    if mode == "push":
         try:
-            result['filelist_initial'] = gather_files(module.params['file_root'], exclude=module.params['exclude'], include=module.params['include'])
-            result['filelist_typed'] = determine_mimetypes(result['filelist_initial'], module.params.get('mime_map'))
-            result['filelist_s3'] = calculate_s3_path(result['filelist_typed'], module.params['key_prefix'])
-            result['filelist_local_etag'] = calculate_local_etag(result['filelist_s3'])
-            result['filelist_actionable'] = filter_list(s3, module.params['bucket'], result['filelist_local_etag'], module.params['file_change_strategy'])
-            result['uploads'] = upload_files(s3, module.params['bucket'], result['filelist_actionable'], module.params)
+            result["filelist_initial"] = gather_files(
+                module.params["file_root"], exclude=module.params["exclude"], include=module.params["include"]
+            )
+            result["filelist_typed"] = determine_mimetypes(result["filelist_initial"], module.params.get("mime_map"))
+            result["filelist_s3"] = calculate_s3_path(result["filelist_typed"], module.params["key_prefix"])
+            try:
+                result["filelist_local_etag"] = calculate_local_etag(result["filelist_s3"])
+            except ValueError as e:
+                if module.params["file_change_strategy"] == "checksum":
+                    module.fail_json_aws(
+                        e,
+                        "Unable to calculate checksum.  If running in FIPS mode, you may need to use another file_change_strategy",
+                    )
+                result["filelist_local_etag"] = result["filelist_s3"].copy()
+            result["filelist_actionable"] = filter_list(
+                s3, module.params["bucket"], result["filelist_local_etag"], module.params["file_change_strategy"]
+            )
+            result["uploads"] = upload_files(s3, module.params["bucket"], result["filelist_actionable"], module.params)
 
-            if module.params['delete']:
-                result['removed'] = remove_files(s3, result['filelist_local_etag'], module.params)
+            if module.params["delete"]:
+                result["removed"] = remove_files(s3, result["filelist_local_etag"], module.params)
 
             # mark changed if we actually upload something.
-            if result.get('uploads') or result.get('removed'):
-                result['changed'] = True
+            if result.get("uploads") or result.get("removed"):
+                result["changed"] = True
             # result.update(filelist=actionable_filelist)
         except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
             module.fail_json_aws(e, msg="Failed to push file")
@@ -587,5 +552,5 @@ def main():
     module.exit_json(**result)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
