@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
 # Copyright (c) 2024, Felix Fontein <felix@fontein.de>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 name: to_serial
@@ -25,6 +23,7 @@ seealso:
 """
 
 EXAMPLES = r"""
+---
 - name: Convert integer to serial number
   ansible.builtin.debug:
     msg: "{{ 1234567 | community.crypto.to_serial }}"
@@ -39,30 +38,32 @@ _value:
   type: string
 """
 
+from collections.abc import Callable
+
 from ansible.errors import AnsibleFilterError
-from ansible.module_utils.common.text.converters import to_native
-from ansible.module_utils.six import integer_types
 
-from ansible_collections.community.crypto.plugins.module_utils.serial import to_serial
+from ansible_collections.community.crypto.plugins.module_utils._serial import to_serial
 
 
-def to_serial_filter(input):
-    if not isinstance(input, integer_types):
+def to_serial_filter(serial_int: int) -> str:
+    if not isinstance(serial_int, int):
         raise AnsibleFilterError(
-            'The input for the community.crypto.to_serial filter must be an integer; got {type} instead'.format(type=type(input))
+            f"The input for the community.crypto.to_serial filter must be an integer; got {type(serial_int)} instead"
+        )
+    if serial_int < 0:
+        raise AnsibleFilterError(
+            "The input for the community.crypto.to_serial filter must not be negative"
         )
-    if input < 0:
-        raise AnsibleFilterError('The input for the community.crypto.to_serial filter must not be negative')
     try:
-        return to_serial(input)
+        return to_serial(serial_int)
     except ValueError as exc:
-        raise AnsibleFilterError(to_native(exc))
+        raise AnsibleFilterError(str(exc)) from exc
 
 
-class FilterModule(object):
-    '''Ansible jinja2 filters'''
+class FilterModule:
+    """Ansible jinja2 filters"""
 
-    def filters(self):
+    def filters(self) -> dict[str, Callable]:
         return {
-            'to_serial': to_serial_filter,
+            "to_serial": to_serial_filter,
         }
