@@ -1,15 +1,9 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
-
 # Copyright (c) 2024 Felix Fontein <felix@fontein.de>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-
-
-__metaclass__ = type
-
+from __future__ import annotations
 
 DOCUMENTATION = """
 module: acme_certificate_order_create
@@ -19,9 +13,9 @@ short_description: Create an ACME v2 order
 description:
   - Creates an ACME v2 order. This is the first step of obtaining a new certificate
     with the L(ACME protocol,https://tools.ietf.org/html/rfc8555) from a Certificate
-    Authority such as L(Let's Encrypt,https://letsencrypt.org/) or
-    L(Buypass,https://www.buypass.com/). This module does not  support ACME v1, the
-    original version of the ACME protocol before standardization.
+    Authority such as L(Let's Encrypt,https://letsencrypt.org/).
+    This module does not support ACME v1, the original version of the ACME protocol
+    before standardization.
   - The current implementation supports the V(http-01), V(dns-01) and V(tls-alpn-01)
     challenges.
   - This module needs to be used in conjunction with the
@@ -60,10 +54,6 @@ seealso:
     description: Documentation for the Let's Encrypt Certification Authority.
                  Provides useful information for example on rate limits.
     link: https://letsencrypt.org/docs/
-  - name: Buypass Go SSL
-    description: Documentation for the Buypass Certification Authority.
-                 Provides useful information for example on rate limits.
-    link: https://www.buypass.com/ssl/products/acme
   - name: Automatic Certificate Management Environment (ACME)
     description: The specification of the ACME protocol (RFC 8555).
     link: https://tools.ietf.org/html/rfc8555
@@ -85,11 +75,11 @@ seealso:
   - module: community.crypto.acme_inspect
     description: Allows to debug problems.
 extends_documentation_fragment:
-  - community.crypto.acme.basic
-  - community.crypto.acme.account
-  - community.crypto.acme.certificate
-  - community.crypto.attributes
-  - community.crypto.attributes.actiongroup_acme
+  - community.crypto._acme.basic
+  - community.crypto._acme.account
+  - community.crypto._acme.certificate
+  - community.crypto._attributes
+  - community.crypto._attributes.actiongroup_acme
 attributes:
   check_mode:
     support: none
@@ -111,9 +101,9 @@ options:
   replaces_cert_id:
     description:
       - If provided, will request the order to replace the certificate identified by this certificate ID
-        according to L(the ACME ARI draft 3, https://www.ietf.org/archive/id/draft-ietf-acme-ari-03.html#section-5).
+        according to L(Section 5 of RFC 9773, https://www.rfc-editor.org/rfc/rfc9773.html#section-5).
       - This certificate ID must be computed as specified in
-        L(the ACME ARI draft 3, https://www.ietf.org/archive/id/draft-ietf-acme-ari-03.html#section-4.1).
+        L(Section 4.1 of RFC 9773, https://www.rfc-editor.org/rfc/rfc9773.html#section-4.1).
         It is returned as return value RV(community.crypto.acme_certificate_renewal_info#module:cert_id) of the
         M(community.crypto.acme_certificate_renewal_info) module.
       - ACME servers might refuse to create new orders that indicate to replace a certificate for which
@@ -215,7 +205,6 @@ EXAMPLES = r"""
 - name: Create a challenge for sample.com using a account key file.
   community.crypto.acme_certificate_order_create:
     acme_directory: https://acme-v01.api.letsencrypt.org/directory
-    acme_version: 2
     account_key_src: /etc/pki/cert/private/account.key
     csr: /etc/pki/cert/csr/sample.com.csr
   register: sample_com_challenge
@@ -238,7 +227,6 @@ EXAMPLES = r"""
 - name: Let the challenge be validated
   community.crypto.acme_certificate_order_validate:
     acme_directory: https://acme-v01.api.letsencrypt.org/directory
-    acme_version: 2
     account_key_src: /etc/pki/cert/private/account.key
     order_uri: "{{ sample_com_challenge.order_uri }}"
     challenge: dns-01
@@ -246,7 +234,6 @@ EXAMPLES = r"""
 - name: Retrieve the cert and intermediate certificate
   community.crypto.acme_certificate_order_finalize:
     acme_directory: https://acme-v01.api.letsencrypt.org/directory
-    acme_version: 2
     account_key_src: /etc/pki/cert/private/account.key
     csr: /etc/pki/cert/csr/sample.com.csr
     order_uri: "{{ sample_com_challenge.order_uri }}"
@@ -281,6 +268,7 @@ challenge_data:
     challenges:
       description:
         - Information for different challenge types supported for this identifier.
+        - Note that the keys are not valid Jinja2 identifiers.
       type: dict
       contains:
         http-01:
@@ -379,39 +367,39 @@ account_uri:
   type: str
 """
 
-from ansible_collections.community.crypto.plugins.module_utils.acme.acme import (
+import typing as t
+
+from ansible_collections.community.crypto.plugins.module_utils._acme.acme import (
     create_backend,
     create_default_argspec,
 )
-from ansible_collections.community.crypto.plugins.module_utils.acme.certificate import (
+from ansible_collections.community.crypto.plugins.module_utils._acme.certificate import (
     ACMECertificateClient,
 )
-from ansible_collections.community.crypto.plugins.module_utils.acme.errors import (
+from ansible_collections.community.crypto.plugins.module_utils._acme.errors import (
     ModuleFailException,
 )
 
 
-def main():
+def main() -> t.NoReturn:
     argument_spec = create_default_argspec(with_certificate=True)
     argument_spec.update_argspec(
-        deactivate_authzs=dict(type="bool", default=True),
-        replaces_cert_id=dict(type="str"),
-        profile=dict(type="str"),
-        order_creation_error_strategy=dict(
-            type="str",
-            default="auto",
-            choices=["auto", "always", "fail", "retry_without_replaces_cert_id"],
-        ),
-        order_creation_max_retries=dict(type="int", default=3),
+        deactivate_authzs={"type": "bool", "default": True},
+        replaces_cert_id={"type": "str"},
+        profile={"type": "str"},
+        order_creation_error_strategy={
+            "type": "str",
+            "default": "auto",
+            "choices": ["auto", "always", "fail", "retry_without_replaces_cert_id"],
+        },
+        order_creation_max_retries={"type": "int", "default": 3},
     )
     module = argument_spec.create_ansible_module()
-    if module.params["acme_version"] == 1:
-        module.fail_json("The module does not support acme_version=1")
 
-    backend = create_backend(module, False)
+    backend = create_backend(module, needs_acme_v2=False)
 
     try:
-        client = ACMECertificateClient(module, backend)
+        client = ACMECertificateClient(module=module, backend=backend)
 
         profile = module.params["profile"]
         if profile is not None:
@@ -424,9 +412,7 @@ def main():
                 )
             if profile not in meta_profiles:
                 raise ModuleFailException(
-                    msg="The ACME CA does not support selected profile {0!r}.".format(
-                        profile
-                    )
+                    msg=f"The ACME CA does not support selected profile {profile!r}."
                 )
 
         order = None
@@ -449,7 +435,7 @@ def main():
             challenge_data_dns=data_dns,
         )
     except ModuleFailException as e:
-        e.do_fail(module)
+        e.do_fail(module=module)
 
 
 if __name__ == "__main__":
