@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 
 # Copyright (c) 2016, Ben Doherty <bendohmv@gmail.com>
 # Sponsored by Oomph, Inc. http://www.oomphinc.com
@@ -7,14 +6,13 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 module: archive
 short_description: Creates a compressed archive of one or more files or trees
 extends_documentation_fragment:
-  - files
+  - ansible.builtin.files
   - community.general.attributes
 description:
   - Creates or extends an archive.
@@ -74,11 +72,8 @@ options:
     default: false
 notes:
   - Can produce C(gzip), C(bzip2), C(lzma), and C(zip) compressed files or archives.
-  - This module uses C(tarfile), C(zipfile), C(gzip), and C(bz2) packages on the target host to create archives. These are
-    part of the Python standard library for Python 2 and 3.
-requirements:
-  - Requires C(lzma) (standard library of Python 3) or L(backports.lzma, https://pypi.org/project/backports.lzma/) (Python
-    2) if using C(xz) format.
+  - This module uses C(tarfile), C(zipfile), C(gzip), C(bz2), and C(lzma) packages on the target host to create archives. These are
+    part of the Python standard library.
 seealso:
   - module: ansible.builtin.unarchive
 author:
@@ -184,51 +179,29 @@ import bz2
 import glob
 import gzip
 import io
+import lzma
 import os
 import re
 import shutil
 import tarfile
 import zipfile
 from fnmatch import fnmatch
-from sys import version_info
 from traceback import format_exc
+from zipfile import BadZipFile
 from zlib import crc32
 
-from ansible.module_utils.basic import AnsibleModule, missing_required_lib
+from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.common.text.converters import to_bytes, to_native
-from ansible.module_utils import six
 
-try:  # python 3.2+
-    from zipfile import BadZipFile  # type: ignore[attr-defined]
-except ImportError:  # older python
-    from zipfile import BadZipfile as BadZipFile
 
-LZMA_IMP_ERR = None
-if six.PY3:
-    try:
-        import lzma
-        HAS_LZMA = True
-    except ImportError:
-        LZMA_IMP_ERR = format_exc()
-        HAS_LZMA = False
-else:
-    try:
-        from backports import lzma
-        HAS_LZMA = True
-    except ImportError:
-        LZMA_IMP_ERR = format_exc()
-        HAS_LZMA = False
-
-PY27 = version_info[0:2] >= (2, 7)
-
-STATE_ABSENT = 'absent'
-STATE_ARCHIVED = 'archive'
-STATE_COMPRESSED = 'compress'
-STATE_INCOMPLETE = 'incomplete'
+STATE_ABSENT = "absent"
+STATE_ARCHIVED = "archive"
+STATE_COMPRESSED = "compress"
+STATE_INCOMPLETE = "incomplete"
 
 
 def common_path(paths):
-    empty = b'' if paths and isinstance(paths[0], six.binary_type) else ''
+    empty = b"" if paths and isinstance(paths[0], bytes) else ""
 
     return os.path.join(
         os.path.dirname(os.path.commonprefix([os.path.join(os.path.dirname(p), empty) for p in paths])), empty
@@ -240,7 +213,7 @@ def expand_paths(paths):
     is_globby = False
     for path in paths:
         b_path = _to_bytes(path)
-        if b'*' in b_path or b'?' in b_path:
+        if b"*" in b_path or b"?" in b_path:
             e_paths = glob.glob(b_path)
             is_globby = True
         else:
@@ -254,35 +227,34 @@ def matches_exclusion_patterns(path, exclusion_patterns):
 
 
 def is_archive(path):
-    return re.search(br'\.(tar|tar\.(gz|bz2|xz)|tgz|tbz2|zip)$', os.path.basename(path), re.IGNORECASE)
+    return re.search(rb"\.(tar|tar\.(gz|bz2|xz)|tgz|tbz2|zip)$", os.path.basename(path), re.IGNORECASE)
 
 
 def strip_prefix(prefix, string):
-    return string[len(prefix):] if string.startswith(prefix) else string
+    return string[len(prefix) :] if string.startswith(prefix) else string
 
 
 def _to_bytes(s):
-    return to_bytes(s, errors='surrogate_or_strict')
+    return to_bytes(s, errors="surrogate_or_strict")
 
 
 def _to_native(s):
-    return to_native(s, errors='surrogate_or_strict')
+    return to_native(s, errors="surrogate_or_strict")
 
 
 def _to_native_ascii(s):
-    return to_native(s, errors='surrogate_or_strict', encoding='ascii')
+    return to_native(s, errors="surrogate_or_strict", encoding="ascii")
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Archive(object):
+class Archive(metaclass=abc.ABCMeta):
     def __init__(self, module):
         self.module = module
 
-        self.destination = _to_bytes(module.params['dest']) if module.params['dest'] else None
-        self.exclusion_patterns = module.params['exclusion_patterns'] or []
-        self.format = module.params['format']
-        self.must_archive = module.params['force_archive']
-        self.remove = module.params['remove']
+        self.destination = _to_bytes(module.params["dest"]) if module.params["dest"] else None
+        self.exclusion_patterns = module.params["exclusion_patterns"] or []
+        self.format = module.params["format"]
+        self.must_archive = module.params["force_archive"]
+        self.remove = module.params["remove"]
 
         self.changed = False
         self.destination_state = STATE_ABSENT
@@ -292,18 +264,18 @@ class Archive(object):
         self.targets = []
         self.not_found = []
 
-        paths = module.params['path']
+        paths = module.params["path"]
         self.expanded_paths, has_globs = expand_paths(paths)
-        self.expanded_exclude_paths = expand_paths(module.params['exclude_path'])[0]
+        self.expanded_exclude_paths = expand_paths(module.params["exclude_path"])[0]
 
         self.paths = sorted(set(self.expanded_paths) - set(self.expanded_exclude_paths))
 
         if not self.paths:
             module.fail_json(
-                path=', '.join(paths),
-                expanded_paths=_to_native(b', '.join(self.expanded_paths)),
-                expanded_exclude_paths=_to_native(b', '.join(self.expanded_exclude_paths)),
-                msg='Error, no source paths were found'
+                path=", ".join(paths),
+                expanded_paths=_to_native(b", ".join(self.expanded_paths)),
+                expanded_exclude_paths=_to_native(b", ".join(self.expanded_exclude_paths)),
+                msg="Error, no source paths were found",
             )
 
         self.root = common_path(self.paths)
@@ -312,13 +284,13 @@ class Archive(object):
             self.must_archive = any([has_globs, os.path.isdir(self.paths[0]), len(self.paths) > 1])
 
         if not self.destination and not self.must_archive:
-            self.destination = b'%s.%s' % (self.paths[0], _to_bytes(self.format))
+            self.destination = b"%s.%s" % (self.paths[0], _to_bytes(self.format))
 
         if self.must_archive and not self.destination:
             module.fail_json(
                 dest=_to_native(self.destination),
-                path=', '.join(paths),
-                msg='Error, must specify "dest" when archiving multiple files or trees'
+                path=", ".join(paths),
+                msg='Error, must specify "dest" when archiving multiple files or trees',
             )
 
         if self.remove:
@@ -333,18 +305,18 @@ class Archive(object):
             if self.contains(_to_native(archive_name)):
                 self.successes.append(path)
         except Exception as e:
-            self.errors.append('%s: %s' % (_to_native_ascii(path), _to_native(e)))
+            self.errors.append(f"{_to_native_ascii(path)}: {e}")
 
     def add_single_target(self, path):
-        if self.format in ('zip', 'tar'):
+        if self.format in ("zip", "tar"):
             self.open()
             self.add(path, strip_prefix(self.root, path))
             self.close()
             self.destination_state = STATE_ARCHIVED
         else:
             try:
-                f_out = self._open_compressed_file(_to_native_ascii(self.destination), 'wb')
-                with open(path, 'rb') as f_in:
+                f_out = self._open_compressed_file(_to_native_ascii(self.destination), "wb")
+                with open(path, "rb") as f_in:
                     shutil.copyfileobj(f_in, f_out)
                 f_out.close()
                 self.successes.append(path)
@@ -353,7 +325,8 @@ class Archive(object):
                 self.module.fail_json(
                     path=_to_native(path),
                     dest=_to_native(self.destination),
-                    msg='Unable to write to compressed file: %s' % _to_native(e), exception=format_exc()
+                    msg=f"Unable to write to compressed file: {e}",
+                    exception=format_exc(),
                 )
 
     def add_targets(self):
@@ -372,21 +345,19 @@ class Archive(object):
                 else:
                     self.add(target, strip_prefix(self.root, target))
         except Exception as e:
-            if self.format in ('zip', 'tar'):
+            if self.format in ("zip", "tar"):
                 archive_format = self.format
             else:
-                archive_format = 'tar.' + self.format
+                archive_format = f"tar.{self.format}"
             self.module.fail_json(
-                msg='Error when writing %s archive at %s: %s' % (
-                    archive_format, _to_native(self.destination), _to_native(e)
-                ),
-                exception=format_exc()
+                msg=f"Error when writing {archive_format} archive at {_to_native(self.destination)}: {e}",
+                exception=format_exc(),
             )
         self.close()
 
         if self.errors:
             self.module.fail_json(
-                msg='Errors when writing archive at %s: %s' % (_to_native(self.destination), '; '.join(self.errors))
+                msg=f"Errors when writing archive at {_to_native(self.destination)}: {'; '.join(self.errors)}"
             )
 
     def is_different_from_original(self):
@@ -427,8 +398,7 @@ class Archive(object):
             os.remove(path)
         except OSError as e:
             self.module.fail_json(
-                path=_to_native(path),
-                msg='Unable to remove source file: %s' % _to_native(e), exception=format_exc()
+                path=_to_native(path), msg=f"Unable to remove source file: {e}", exception=format_exc()
             )
 
     def remove_targets(self):
@@ -450,7 +420,7 @@ class Archive(object):
 
         if self.errors:
             self.module.fail_json(
-                dest=_to_native(self.destination), msg='Error deleting some source files: ', files=self.errors
+                dest=_to_native(self.destination), msg="Error deleting some source files: ", files=self.errors
             )
 
     def update_permissions(self):
@@ -460,34 +430,34 @@ class Archive(object):
     @property
     def result(self):
         return {
-            'archived': [_to_native(p) for p in self.successes],
-            'dest': _to_native(self.destination),
-            'dest_state': self.destination_state,
-            'changed': self.changed,
-            'arcroot': _to_native(self.root),
-            'missing': [_to_native(p) for p in self.not_found],
-            'expanded_paths': [_to_native(p) for p in self.expanded_paths],
-            'expanded_exclude_paths': [_to_native(p) for p in self.expanded_exclude_paths],
+            "archived": [_to_native(p) for p in self.successes],
+            "dest": _to_native(self.destination),
+            "dest_state": self.destination_state,
+            "changed": self.changed,
+            "arcroot": _to_native(self.root),
+            "missing": [_to_native(p) for p in self.not_found],
+            "expanded_paths": [_to_native(p) for p in self.expanded_paths],
+            "expanded_exclude_paths": [_to_native(p) for p in self.expanded_exclude_paths],
         }
 
     def _check_removal_safety(self):
         for path in self.paths:
-            if os.path.isdir(path) and self.destination.startswith(os.path.join(path, b'')):
+            if os.path.isdir(path) and self.destination.startswith(os.path.join(path, b"")):
                 self.module.fail_json(
-                    path=b', '.join(self.paths),
-                    msg='Error, created archive can not be contained in source paths when remove=true'
+                    path=b", ".join(self.paths),
+                    msg="Error, created archive can not be contained in source paths when remove=true",
                 )
 
     def _open_compressed_file(self, path, mode):
         f = None
-        if self.format == 'gz':
+        if self.format == "gz":
             f = gzip.open(path, mode)
-        elif self.format == 'bz2':
+        elif self.format == "bz2":
             f = bz2.BZ2File(path, mode)
-        elif self.format == 'xz':
+        elif self.format == "xz":
             f = lzma.LZMAFile(path, mode)
         else:
-            self.module.fail_json(msg="%s is not a valid format" % self.format)
+            self.module.fail_json(msg=f"{self.format} is not a valid format")
 
         return f
 
@@ -514,7 +484,7 @@ class Archive(object):
 
 class ZipArchive(Archive):
     def __init__(self, module):
-        super(ZipArchive, self).__init__(module)
+        super().__init__(module)
 
     def close(self):
         self.file.close()
@@ -527,7 +497,7 @@ class ZipArchive(Archive):
         return True
 
     def open(self):
-        self.file = zipfile.ZipFile(_to_native_ascii(self.destination), 'w', zipfile.ZIP_DEFLATED, True)
+        self.file = zipfile.ZipFile(_to_native_ascii(self.destination), "w", zipfile.ZIP_DEFLATED, True)
 
     def _add(self, path, archive_name):
         if not matches_exclusion_patterns(path, self.exclusion_patterns):
@@ -535,7 +505,7 @@ class ZipArchive(Archive):
 
     def _get_checksums(self, path):
         try:
-            archive = zipfile.ZipFile(_to_native_ascii(path), 'r')
+            archive = zipfile.ZipFile(_to_native_ascii(path), "r")
             checksums = set((info.filename, info.CRC) for info in archive.infolist())
             archive.close()
         except BadZipFile:
@@ -545,13 +515,13 @@ class ZipArchive(Archive):
 
 class TarArchive(Archive):
     def __init__(self, module):
-        super(TarArchive, self).__init__(module)
+        super().__init__(module)
         self.fileIO = None
 
     def close(self):
         self.file.close()
-        if self.format == 'xz':
-            with lzma.open(_to_native(self.destination), 'wb') as f:
+        if self.format == "xz":
+            with lzma.open(_to_native(self.destination), "wb") as f:
                 f.write(self.fileIO.getvalue())
             self.fileIO.close()
 
@@ -563,58 +533,49 @@ class TarArchive(Archive):
         return True
 
     def open(self):
-        if self.format in ('gz', 'bz2'):
-            self.file = tarfile.open(_to_native_ascii(self.destination), 'w|' + self.format)
+        if self.format in ("gz", "bz2"):
+            self.file = tarfile.open(_to_native_ascii(self.destination), f"w|{self.format}")
         # python3 tarfile module allows xz format but for python2 we have to create the tarfile
         # in memory and then compress it with lzma.
-        elif self.format == 'xz':
+        elif self.format == "xz":
             self.fileIO = io.BytesIO()
-            self.file = tarfile.open(fileobj=self.fileIO, mode='w')
-        elif self.format == 'tar':
-            self.file = tarfile.open(_to_native_ascii(self.destination), 'w')
+            self.file = tarfile.open(fileobj=self.fileIO, mode="w")
+        elif self.format == "tar":
+            self.file = tarfile.open(_to_native_ascii(self.destination), "w")
         else:
-            self.module.fail_json(msg="%s is not a valid archive format" % self.format)
+            self.module.fail_json(msg=f"{self.format} is not a valid archive format")
 
     def _add(self, path, archive_name):
-        def py27_filter(tarinfo):
+        def filter(tarinfo):
             return None if matches_exclusion_patterns(tarinfo.name, self.exclusion_patterns) else tarinfo
 
-        def py26_filter(path):
-            return matches_exclusion_patterns(path, self.exclusion_patterns)
-
-        if PY27:
-            self.file.add(path, archive_name, recursive=False, filter=py27_filter)
-        else:
-            self.file.add(path, archive_name, recursive=False, exclude=py26_filter)
+        self.file.add(path, archive_name, recursive=False, filter=filter)
 
     def _get_checksums(self, path):
-        if HAS_LZMA:
-            LZMAError = lzma.LZMAError
-        else:
-            # Just picking another exception that's also listed below
-            LZMAError = tarfile.ReadError
+        LZMAError = lzma.LZMAError
+
         try:
-            if self.format == 'xz':
-                with lzma.open(_to_native_ascii(path), 'r') as f:
+            if self.format == "xz":
+                with lzma.open(_to_native_ascii(path), "r") as f:
                     archive = tarfile.open(fileobj=f)
                     checksums = set((info.name, info.chksum) for info in archive.getmembers())
                     archive.close()
             else:
-                archive = tarfile.open(_to_native_ascii(path), 'r|' + self.format)
+                archive = tarfile.open(_to_native_ascii(path), f"r|{self.format}")
                 checksums = set((info.name, info.chksum) for info in archive.getmembers())
                 archive.close()
         except (LZMAError, tarfile.ReadError, tarfile.CompressionError):
             try:
                 # The python implementations of gzip, bz2, and lzma do not support restoring compressed files
                 # to their original names so only file checksum is returned
-                f = self._open_compressed_file(_to_native_ascii(path), 'r')
+                f = self._open_compressed_file(_to_native_ascii(path), "r")
                 checksum = 0
                 while True:
                     chunk = f.read(16 * 1024 * 1024)
                     if not chunk:
                         break
                     checksum = crc32(chunk, checksum)
-                checksums = set([(b'', checksum)])
+                checksums = set([(b"", checksum)])
                 f.close()
             except Exception:
                 checksums = set()
@@ -622,31 +583,31 @@ class TarArchive(Archive):
 
 
 def get_archive(module):
-    if module.params['format'] == 'zip':
+    if module.params["format"] == "zip":
         return ZipArchive(module)
     else:
         return TarArchive(module)
 
 
-def main():
+def create_module() -> AnsibleModule:
     module = AnsibleModule(
         argument_spec=dict(
-            path=dict(type='list', elements='path', required=True),
-            format=dict(type='str', default='gz', choices=['bz2', 'gz', 'tar', 'xz', 'zip']),
-            dest=dict(type='path'),
-            exclude_path=dict(type='list', elements='path', default=[]),
-            exclusion_patterns=dict(type='list', elements='path'),
-            force_archive=dict(type='bool', default=False),
-            remove=dict(type='bool', default=False),
+            path=dict(type="list", elements="path", required=True),
+            format=dict(type="str", default="gz", choices=["bz2", "gz", "tar", "xz", "zip"]),
+            dest=dict(type="path"),
+            exclude_path=dict(type="list", elements="path", default=[]),
+            exclusion_patterns=dict(type="list", elements="path"),
+            force_archive=dict(type="bool", default=False),
+            remove=dict(type="bool", default=False),
         ),
         add_file_common_args=True,
         supports_check_mode=True,
     )
+    return module
 
-    if not HAS_LZMA and module.params['format'] == 'xz':
-        module.fail_json(
-            msg=missing_required_lib("lzma or backports.lzma", reason="when using xz format"), exception=LZMA_IMP_ERR
-        )
+
+def main():
+    module = create_module()
 
     check_mode = module.check_mode
 
@@ -682,5 +643,5 @@ def main():
     module.exit_json(**archive.result)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
