@@ -6,11 +6,10 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 import atexit
-import ansible.module_utils.common._collections_compat as collections_compat
+from collections.abc import Mapping
 import json
 import os
 import re
@@ -22,6 +21,8 @@ import traceback
 import datetime
 from collections import OrderedDict
 from ansible.module_utils.compat.version import StrictVersion
+from ansible_collections.vmware.vmware.plugins.module_utils.clients.errors import ApiAccessError
+from ansible_collections.vmware.vmware.plugins.module_utils.clients.pyvmomi import PyvmomiClient
 from random import randint
 
 
@@ -37,18 +38,16 @@ except ImportError:
 PYVMOMI_IMP_ERR = None
 try:
     from pyVim import connect
-    from pyVmomi import vim, vmodl, VmomiSupport
+    from pyVmomi import vim, vmodl, VmomiSupport, VmomiJSONEncoder
     HAS_PYVMOMI = True
-    HAS_PYVMOMIJSON = hasattr(VmomiSupport, 'VmomiJSONEncoder')
 except ImportError:
     PYVMOMI_IMP_ERR = traceback.format_exc()
     HAS_PYVMOMI = False
-    HAS_PYVMOMIJSON = False
 
-from ansible.module_utils._text import to_text, to_native
-from ansible.module_utils.six import integer_types, iteritems, string_types, raise_from
-from ansible.module_utils.basic import env_fallback, missing_required_lib
-from ansible.module_utils.six.moves.urllib.parse import unquote
+from ansible.module_utils.common.text.converters import to_text, to_native
+from ansible.module_utils.basic import missing_required_lib
+from urllib.parse import unquote
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 
 
 class TaskError(Exception):
@@ -56,11 +55,6 @@ class TaskError(Exception):
         super(TaskError, self).__init__(*args, **kwargs)
 
 
-class ApiAccessError(Exception):
-    def __init__(self, *args, **kwargs):
-        super(ApiAccessError, self).__init__(*args, **kwargs)
-
-
 def check_answer_question_status(vm):
     """Check whether locked a virtual machine.
 
@@ -155,7 +149,7 @@ def wait_for_task(task, max_backoff=64, timeout=3600, vm=None, answers=None):
             except AttributeError:
                 pass
             finally:
-                raise_from(TaskError(error_msg, host_thumbprint), task.info.error)
+                raise TaskError(error_msg, host_thumbprint) from task.info.error
         if task.info.state in [vim.TaskInfo.State.running, vim.TaskInfo.State.queued]:
             sleep_time = min(2 ** failure_counter + randint(1, 1000) / 1000, max_backoff)
             time.sleep(sleep_time)
@@ -455,7 +449,7 @@ def gather_vm_facts(content, vm):
         'instance_uuid': vm.config.instanceUuid,
         'guest_tools_status': _get_vm_prop(vm, ('guest', 'toolsRunningStatus')),
         'guest_tools_version': _get_vm_prop(vm, ('guest', 'toolsVersion')),
-        'guest_question': json.loads(json.dumps(vm.summary.runtime.question, cls=VmomiSupport.VmomiJSONEncoder,
+        'guest_question': json.loads(json.dumps(vm.summary.runtime.question, cls=VmomiJSONEncoder.VmomiJSONEncoder,
                                                 sort_keys=True, strip_dynamic=True)),
         'guest_consolidation_needed': vm.summary.runtime.consolidationNeeded,
         'ipv4': None,
@@ -676,37 +670,7 @@ def get_vnc_extraconfig(vm):
 
 
 def vmware_argument_spec():
-    return dict(
-        hostname=dict(type='str',
-                      required=False,
-                      fallback=(env_fallback, ['VMWARE_HOST']),
-                      ),
-        username=dict(type='str',
-                      aliases=['user', 'admin'],
-                      required=False,
-                      fallback=(env_fallback, ['VMWARE_USER'])),
-        password=dict(type='str',
-                      aliases=['pass', 'pwd'],
-                      required=False,
-                      no_log=True,
-                      fallback=(env_fallback, ['VMWARE_PASSWORD'])),
-        port=dict(type='int',
-                  default=443,
-                  fallback=(env_fallback, ['VMWARE_PORT'])),
-        validate_certs=dict(type='bool',
-                            required=False,
-                            default=True,
-                            fallback=(env_fallback, ['VMWARE_VALIDATE_CERTS'])
-                            ),
-        proxy_host=dict(type='str',
-                        required=False,
-                        default=None,
-                        fallback=(env_fallback, ['VMWARE_PROXY_HOST'])),
-        proxy_port=dict(type='int',
-                        required=False,
-                        default=None,
-                        fallback=(env_fallback, ['VMWARE_PROXY_PORT'])),
-    )
+    return base_argument_spec()
 
 
 def connect_to_api(module, disconnect_atexit=True, return_si=False, hostname=None, username=None, password=None, port=None, validate_certs=None,
@@ -826,59 +790,6 @@ def get_all_objs(content, vimtype, folder=None, recurse=True):
     return obj
 
 
-def run_command_in_guest(content, vm, username, password, program_path, program_args, program_cwd, program_env):
-
-    result = {'failed': False}
-
-    tools_status = vm.guest.toolsStatus
-    if (tools_status == 'toolsNotInstalled' or tools_status == 'toolsNotRunning'):
-        result['failed'] = True
-        result['msg'] = "VMwareTools is not installed or is not running in the guest"
-        return result
-
-    # https://github.com/vmware/pyvmomi/blob/master/docs/vim/vm/guest/NamePasswordAuthentication.rst
-    creds = vim.vm.guest.NamePasswordAuthentication(
-        username=username, password=password
-    )
-
-    try:
-        # https://github.com/vmware/pyvmomi/blob/master/docs/vim/vm/guest/ProcessManager.rst
-        pm = content.guestOperationsManager.processManager
-        # https://www.vmware.com/support/developer/converter-sdk/conv51_apireference/vim.vm.guest.ProcessManager.ProgramSpec.html
-        ps = vim.vm.guest.ProcessManager.ProgramSpec(
-            # programPath=program,
-            # arguments=args
-            programPath=program_path,
-            arguments=program_args,
-            workingDirectory=program_cwd,
-        )
-
-        res = pm.StartProgramInGuest(vm, creds, ps)
-        result['pid'] = res
-        pdata = pm.ListProcessesInGuest(vm, creds, [res])
-
-        # wait for pid to finish
-        while not pdata[0].endTime:
-            time.sleep(1)
-            pdata = pm.ListProcessesInGuest(vm, creds, [res])
-
-        result['owner'] = pdata[0].owner
-        result['startTime'] = pdata[0].startTime.isoformat()
-        result['endTime'] = pdata[0].endTime.isoformat()
-        result['exitCode'] = pdata[0].exitCode
-        if result['exitCode'] != 0:
-            result['failed'] = True
-            result['msg'] = "program exited non-zero"
-        else:
-            result['msg'] = "program completed successfully"
-
-    except Exception as e:
-        result['msg'] = str(e)
-        result['failed'] = True
-
-    return result
-
-
 def serialize_spec(clonespec):
     """Serialize a clonespec or a relocation spec"""
     data = {}
@@ -914,8 +825,8 @@ def serialize_spec(clonespec):
             data[x] = []
             for xe in xo:
                 data[x].append(serialize_spec(xe))
-        elif issubclass(xt, string_types + integer_types + (float, bool)):
-            if issubclass(xt, integer_types):
+        elif issubclass(xt, (str, int, float, bool)):
+            if issubclass(xt, int):
                 data[x] = int(xo)
             else:
                 data[x] = to_text(xo)
@@ -1088,11 +999,11 @@ def option_diff(options, current_options, truthy_strings_as_bool=True):
     for option_key, option_value in options.items():
         if truthy_strings_as_bool and is_boolean(option_value):
             option_value = VmomiSupport.vmodlTypes['bool'](is_truthy(option_value))
-        elif type(option_value) is int:
+        elif isinstance(option_value, int):
             option_value = VmomiSupport.vmodlTypes['int'](option_value)
-        elif type(option_value) is float:
+        elif isinstance(option_value, float):
             option_value = VmomiSupport.vmodlTypes['float'](option_value)
-        elif type(option_value) is str:
+        elif isinstance(option_value, str):
             option_value = VmomiSupport.vmodlTypes['string'](option_value)
 
         if option_key not in current_options_dict or current_options_dict[option_key] != option_value:
@@ -1122,11 +1033,9 @@ def quote_obj_name(object_name=None):
     return object_name
 
 
-class PyVmomi(object):
+class PyVmomi(PyvmomiClient):
     def __init__(self, module):
-        """
-        Constructor
-        """
+        self.module = module
         if not HAS_REQUESTS:
             module.fail_json(msg=missing_required_lib('requests'),
                              exception=REQUESTS_IMP_ERR)
@@ -1135,10 +1044,18 @@ class PyVmomi(object):
             module.fail_json(msg=missing_required_lib('PyVmomi'),
                              exception=PYVMOMI_IMP_ERR)
 
-        self.module = module
+        try:
+            super().__init__(hostname=module.params['hostname'],
+                             username=module.params['username'],
+                             password=module.params['password'],
+                             port=module.params['port'],
+                             validate_certs=module.params['validate_certs'],
+                             http_proxy_host=module.params['proxy_host'],
+                             http_proxy_port=module.params['proxy_port'])
+        except ApiAccessError as aae:
+            module.fail_json(msg=str(aae))
         self.params = module.params
         self.current_vm_obj = None
-        self.si, self.content = connect_to_api(self.module, return_si=True)
         self.custom_field_mgr = []
         if self.content.customFieldsManager:  # not an ESXi
             self.custom_field_mgr = self.content.customFieldsManager.field
@@ -1174,9 +1091,9 @@ class PyVmomi(object):
         self.module.fail_json(msg='The passed vCenter version: %s is None.' % version)
 
     def get_cert_fingerprint(self, fqdn, port, proxy_host=None, proxy_port=None):
-        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        sock.settimeout(1)
         if proxy_host:
+            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            sock.settimeout(1)
             sock.connect((
                 proxy_host,
                 proxy_port))
@@ -1191,17 +1108,16 @@ class PyVmomi(object):
             der_cert_bin = ctx.wrap_socket(sock, server_hostname=fqdn).getpeercert(True)
             sock.close()
         else:
-            wrapped_socket = ssl.wrap_socket(sock)
             try:
-                wrapped_socket.connect((fqdn, port))
-            except socket.error as socket_error:
-                self.module.fail_json(msg="Cannot connect to host : %s" % socket_error)
-            else:
-                der_cert_bin = wrapped_socket.getpeercert(True)
-                wrapped_socket.close()
-
-        string = str(hashlib.sha1(der_cert_bin).hexdigest())
-        return ':'.join(a + b for a, b in zip(string[::2], string[1::2]))
+                pem = ssl.get_server_certificate((fqdn, port))
+            except Exception:
+                self.module.fail_json(msg=f"Cannot connect to host: {fqdn}")
+            der_cert_bin = ssl.PEM_cert_to_DER_cert(pem)
+        if der_cert_bin:
+            string = str(hashlib.sha1(der_cert_bin).hexdigest())
+            return ':'.join(a + b for a, b in zip(string[::2], string[1::2]))
+        else:
+            self.module.fail_json(msg=f"Unable to obtain certificate fingerprint for host: {fqdn}")
 
     def get_managed_objects_properties(self, vim_type, properties=None):
         """
@@ -1282,9 +1198,9 @@ class PyVmomi(object):
             # following code tries to find user desired one depending upon the folder specified.
             if len(vms) > 1:
                 # We have found multiple virtual machines, decide depending upon folder value
-                if self.params['folder'] is None:
+                if self.params['folder'] is None or self.params['datacenter'] is None:
                     self.module.fail_json(msg="Multiple virtual machines with same name [%s] found, "
-                                          "Folder value is a required parameter to find uniqueness "
+                                          "try to specify folder and / or datacenter to ensure uniqueness "
                                           "of the virtual machine" % self.params['name'],
                                           details="Please see documentation of the vmware_guest module "
                                           "for folder parameter.")
@@ -1337,7 +1253,7 @@ class PyVmomi(object):
                 elif self.params['folder'] in actual_vm_folder_path:
                     vm_obj = vms[0]
         elif 'moid' in self.params and self.params['moid']:
-            vm_obj = VmomiSupport.templateOf('VirtualMachine')(self.params['moid'], self.si._stub)
+            vm_obj = VmomiJSONEncoder.templateOf('VirtualMachine')(self.params['moid'], self.si._stub)
             try:
                 getattr(vm_obj, 'name')
             except vmodl.fault.ManagedObjectNotFound:
@@ -1875,6 +1791,30 @@ class PyVmomi(object):
 
         return None
 
+    def find_first_class_disks(self, datastore_obj):
+        """
+        Get first-class disks managed object
+        Args:
+            datastore_obj: Managed object of datastore
+
+        Returns: First-class disks managed object if found else None
+
+        """
+
+        disks = []
+
+        if self.is_vcenter():
+            for id in self.content.vStorageObjectManager.ListVStorageObject(datastore_obj):
+                disks.append(self.content.vStorageObjectManager.RetrieveVStorageObject(id, datastore_obj))
+
+        else:
+            for id in self.content.vStorageObjectManager.HostListVStorageObject(datastore_obj):
+                disks.append(self.content.vStorageObjectManager.HostRetrieveVStorageObject(id, datastore_obj))
+
+        if disks == []:
+            return None
+        else:
+            return disks
     #
     # Conversion to JSON
     #
@@ -1887,8 +1827,6 @@ class PyVmomi(object):
           https://bit.ly/2EDOs1B (stackoverflow question 3232943)
         License:
           cc-by-sa 3.0 (https://creativecommons.org/licenses/by-sa/3.0/)
-        Changes:
-          using collections_compat for compatibility
 
         Args:
           - d (dict): dict to merge into
@@ -1897,8 +1835,8 @@ class PyVmomi(object):
         Returns:
           dict, with u merged into d
         """
-        for k, v in iteritems(u):
-            if isinstance(v, collections_compat.Mapping):
+        for k, v in u.items():
+            if isinstance(v, Mapping):
                 d[k] = self._deepmerge(d.get(k, {}), v)
             else:
                 d[k] = v
@@ -1939,7 +1877,7 @@ class PyVmomi(object):
         Return:
           dict
         """
-        return json.loads(json.dumps(obj, cls=VmomiSupport.VmomiJSONEncoder,
+        return json.loads(json.dumps(obj, cls=VmomiJSONEncoder.VmomiJSONEncoder,
                                      sort_keys=True, strip_dynamic=True))
 
     def to_json(self, obj, properties=None):
@@ -1949,9 +1887,6 @@ class PyVmomi(object):
         provided then all properties are deeply converted.  The resulting
         JSON is sorted to improve human readability.
 
-        Requires upstream support from pyVmomi > 6.7.1
-        (https://github.com/vmware/pyvmomi/pull/732)
-
         Args:
           - obj (object): vim object
           - properties (list, optional): list of properties following
@@ -1962,9 +1897,6 @@ class PyVmomi(object):
         Return:
           dict
         """
-        if not HAS_PYVMOMIJSON:
-            self.module.fail_json(msg='The installed version of pyvmomi lacks JSON output support; need pyvmomi>6.7.1')
-
         result = dict()
         if properties:
             for prop in properties:
@@ -2012,7 +1944,7 @@ class PyVmomi(object):
         :return: Managed Object if it exists else None
         """
 
-        obj = VmomiSupport.templateOf(object_type)(moid, self.si._stub)
+        obj = VmomiJSONEncoder.templateOf(object_type)(moid, self.si._stub)
         try:
             getattr(obj, 'name')
         except vmodl.fault.ManagedObjectNotFound:
