@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 # Dell OpenManage Ansible Modules
-# Version 9.3.0
-# Copyright (C) 2019-2024 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 9.12.3
+# Copyright (C) 2019-2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # Redistribution and use in source and binary forms, with or without modification,
 # are permitted provided that the following conditions are met:
@@ -52,13 +52,17 @@ idrac_auth_params = {
 }
 
 SESSION_RESOURCE_COLLECTION = {
-    "SESSION": "/redfish/v1/Sessions",
-    "SESSION_ID": "/redfish/v1/Sessions/{Id}",
+    "SESSION": "/redfish/v1/SessionService/Sessions",
+    "SESSION_ID": "/redfish/v1/SessionService/Sessions/{Id}",
 }
 MANAGER_URI = "/redfish/v1/Managers/iDRAC.Embedded.1"
 EXPORT_URI = "/redfish/v1/Managers/iDRAC.Embedded.1/Actions/Oem/EID_674_Manager.ExportSystemConfiguration"
 IMPORT_URI = "/redfish/v1/Managers/iDRAC.Embedded.1/Actions/Oem/EID_674_Manager.ImportSystemConfiguration"
 IMPORT_PREVIEW = "/redfish/v1/Managers/iDRAC.Embedded.1/Actions/Oem/EID_674_Manager.ImportSystemConfigurationPreview"
+EXPORT_URI_17 = "/redfish/v1/Managers/iDRAC.Embedded.1/Actions/Oem/OemManager.ExportSystemConfiguration"
+IMPORT_URI_17 = "/redfish/v1/Managers/iDRAC.Embedded.1/Actions/Oem/OemManager.ImportSystemConfiguration"
+IMPORT_PREVIEW_17 = "/redfish/v1/Managers/iDRAC.Embedded.1/Actions/Oem/OemManager.ImportSystemConfigurationPreview"
+GET_IDRAC_MANAGER_ATTRIBUTES_9_10 = "/redfish/v1/Managers/iDRAC.Embedded.1/Oem/Dell/DellAttributes/iDRAC.Embedded.1"
 
 
 class OpenURLResponse(object):
@@ -95,6 +99,42 @@ class OpenURLResponse(object):
         return self.resp.reason
 
 
+def _get_scp_export_uri(generation: int) -> str:
+    if generation >= 17:
+        return EXPORT_URI_17
+    else:
+        return EXPORT_URI
+
+
+def _get_scp_import_uri(generation: int) -> str:
+    if generation >= 17:
+        return IMPORT_URI_17
+    else:
+        return IMPORT_URI
+
+
+def _get_scp_import_preview_uri(generation: int) -> str:
+    if generation >= 17:
+        return IMPORT_PREVIEW_17
+    else:
+        return IMPORT_PREVIEW
+
+
+def process_scp_target(target) -> list[str]:
+    """
+    Process the SCP target.
+    In the older SCP APIs, the target was a comma-separated string.
+    In the newer SCP APIs, which were made mandatory since 17G,
+    the target is a list of strings.
+    This function takes the target in any format and converts them to the
+    required format.
+    target can be a string or a list of strings
+    """
+    if isinstance(target, str):
+        target = target.split(",")
+    return target
+
+
 class iDRACRedfishAPI(object):
     """REST api for iDRAC modules."""
 
@@ -212,10 +252,19 @@ class iDRACRedfishAPI(object):
         """
         firmware_version = None
         response = self.invoke_request(MANAGER_URI, 'GET')
+        generation = 0
         if response.status_code == 200:
             generation = int(re.search(r"\d+(?=G)", response.json_data["Model"]).group())
             firmware_version = response.json_data["FirmwareVersion"]
-        return generation, firmware_version
+        hw_model = ""
+        try:
+            hw_model_out = self.invoke_request(GET_IDRAC_MANAGER_ATTRIBUTES_9_10, 'GET')
+            if hw_model_out.status_code == 200:
+                hw_model = hw_model_out.json_data.get('Attributes', {}).get('Info.1.HWModel', "iDRAC 9")
+        except HTTPError:
+            hw_model = "iDRAC 8"
+
+        return generation, firmware_version, hw_model
 
     def wait_for_job_complete(self, task_uri, job_wait=False):
         """
@@ -228,7 +277,8 @@ class iDRACRedfishAPI(object):
         while job_wait:
             try:
                 response = self.invoke_request(task_uri, "GET")
-                if response.json_data.get("TaskState") == "Running":
+                if response.json_data.get("TaskState") == "Running" or \
+                        response.json_data.get("TaskState") == "New":
                     time.sleep(10)
                 else:
                     break
@@ -256,6 +306,38 @@ class iDRACRedfishAPI(object):
             time.sleep(30)
         return response
 
+    def form_scp_share_param(self, target, share=None):
+        """
+        A function to form the share param body for SCP import and export
+        from the target and Ansible share input dict.
+        share is Optional.
+        """
+        if share is None:
+            share = {}
+        share_param = {
+            "Target": process_scp_target(target)
+        }
+        # Mapping of API body keys to Ansible argument keys
+        scp_share_param_mappings = {
+            "IPAddress": "share_ip",
+            "ShareName": "share_name",
+            "ShareType": "share_type",
+            "FileName": "file_name",
+            "Username": "username",
+            "Password": "password",
+            "IgnoreCertificateWarning": "ignore_certificate_warning",
+            "ProxySupport": "proxy_support",
+            "ProxyType": "proxy_type",
+            "ProxyPort": "proxy_port",
+            "ProxyServer": "proxy_server",
+            "ProxyUserName": "proxy_username",
+            "ProxyPassword": "proxy_password",
+        }
+        for key, param in scp_share_param_mappings.items():
+            if share.get(param) is not None:
+                share_param[key] = share[param]
+        return share_param
+
     def export_scp(self, export_format=None, export_use=None, target=None,
                    job_wait=False, share=None, include_in_export="Default"):
         """
@@ -266,38 +348,13 @@ class iDRACRedfishAPI(object):
         :param job_wait: True or False decide whether to wait till the job completion.
         :return: exported data in requested format.
         """
+        gen_details = self.get_server_generation
+        generation = gen_details[0]
         payload = {"ExportFormat": export_format, "ExportUse": export_use,
-                   "ShareParameters": {"Target": target}}
-        if share is None:
-            share = {}
-        if share.get("share_ip") is not None:
-            payload["ShareParameters"]["IPAddress"] = share["share_ip"]
-        if share.get("share_name") is not None and share.get("share_name"):
-            payload["ShareParameters"]["ShareName"] = share["share_name"]
-        if share.get("share_type") is not None:
-            payload["ShareParameters"]["ShareType"] = share["share_type"]
-        if share.get("file_name") is not None:
-            payload["ShareParameters"]["FileName"] = share["file_name"]
-        if share.get("username") is not None:
-            payload["ShareParameters"]["Username"] = share["username"]
-        if share.get("password") is not None:
-            payload["ShareParameters"]["Password"] = share["password"]
-        if share.get("ignore_certificate_warning") is not None:
-            payload["ShareParameters"]["IgnoreCertificateWarning"] = share["ignore_certificate_warning"]
-        if share.get("proxy_support") is not None:
-            payload["ShareParameters"]["ProxySupport"] = share["proxy_support"]
-        if share.get("proxy_type") is not None:
-            payload["ShareParameters"]["ProxyType"] = share["proxy_type"]
-        if share.get("proxy_port") is not None:
-            payload["ShareParameters"]["ProxyPort"] = share["proxy_port"]
-        if share.get("proxy_server") is not None:
-            payload["ShareParameters"]["ProxyServer"] = share["proxy_server"]
-        if share.get("proxy_username") is not None:
-            payload["ShareParameters"]["ProxyUserName"] = share["proxy_username"]
-        if share.get("proxy_password") is not None:
-            payload["ShareParameters"]["ProxyPassword"] = share["proxy_password"]
-        payload["IncludeInExport"] = include_in_export
-        response = self.invoke_request(EXPORT_URI, "POST", data=payload)
+                   "ShareParameters": self.form_scp_share_param(target, share)}
+        payload["IncludeInExport"] = [include_in_export]
+        export_uri = _get_scp_export_uri(generation)
+        response = self.invoke_request(export_uri, "POST", data=payload)
         if response.status_code == 202 and job_wait:
             task_uri = response.headers["Location"]
             response = self.wait_for_job_complete(task_uri, job_wait=job_wait)
@@ -315,74 +372,24 @@ class iDRACRedfishAPI(object):
         :param share: dictionary which has all the share details.
         :return: json response
         """
+        gen_details = self.get_server_generation
+        generation = gen_details[0]
         payload = {"ShutdownType": shutdown_type, "EndHostPowerState": host_powerstate,
-                   "ShareParameters": {"Target": target}, "TimeToWait": time_to_wait}
+                   "ShareParameters": self.form_scp_share_param(target, share),
+                   "TimeToWait": time_to_wait}
         if import_buffer is not None:
             payload["ImportBuffer"] = import_buffer
-        if share is None:
-            share = {}
-        if share.get("share_ip") is not None:
-            payload["ShareParameters"]["IPAddress"] = share["share_ip"]
-        if share.get("share_name") is not None and share.get("share_name"):
-            payload["ShareParameters"]["ShareName"] = share["share_name"]
-        if share.get("share_type") is not None:
-            payload["ShareParameters"]["ShareType"] = share["share_type"]
-        if share.get("file_name") is not None:
-            payload["ShareParameters"]["FileName"] = share["file_name"]
-        if share.get("username") is not None:
-            payload["ShareParameters"]["Username"] = share["username"]
-        if share.get("password") is not None:
-            payload["ShareParameters"]["Password"] = share["password"]
-        if share.get("ignore_certificate_warning") is not None:
-            payload["ShareParameters"]["IgnoreCertificateWarning"] = share["ignore_certificate_warning"]
-        if share.get("proxy_support") is not None:
-            payload["ShareParameters"]["ProxySupport"] = share["proxy_support"]
-        if share.get("proxy_type") is not None:
-            payload["ShareParameters"]["ProxyType"] = share["proxy_type"]
-        if share.get("proxy_port") is not None:
-            payload["ShareParameters"]["ProxyPort"] = share["proxy_port"]
-        if share.get("proxy_server") is not None:
-            payload["ShareParameters"]["ProxyServer"] = share["proxy_server"]
-        if share.get("proxy_username") is not None:
-            payload["ShareParameters"]["ProxyUserName"] = share["proxy_username"]
-        if share.get("proxy_password") is not None:
-            payload["ShareParameters"]["ProxyPassword"] = share["proxy_password"]
-        response = self.invoke_request(IMPORT_URI, "POST", data=payload)
-        return response
+        import_uri = _get_scp_import_uri(generation)
+        return self.invoke_request(import_uri, "POST", data=payload)
 
     def import_preview(self, import_buffer=None, target=None, share=None, job_wait=False):
-        payload = {"ShareParameters": {"Target": target}}
+        gen_details = self.get_server_generation
+        generation = gen_details[0]
+        payload = {"ShareParameters": self.form_scp_share_param(target, share)}
         if import_buffer is not None:
             payload["ImportBuffer"] = import_buffer
-        if share is None:
-            share = {}
-        if share.get("share_ip") is not None:
-            payload["ShareParameters"]["IPAddress"] = share["share_ip"]
-        if share.get("share_name") is not None and share.get("share_name"):
-            payload["ShareParameters"]["ShareName"] = share["share_name"]
-        if share.get("share_type") is not None:
-            payload["ShareParameters"]["ShareType"] = share["share_type"]
-        if share.get("file_name") is not None:
-            payload["ShareParameters"]["FileName"] = share["file_name"]
-        if share.get("username") is not None:
-            payload["ShareParameters"]["Username"] = share["username"]
-        if share.get("password") is not None:
-            payload["ShareParameters"]["Password"] = share["password"]
-        if share.get("ignore_certificate_warning") is not None:
-            payload["ShareParameters"]["IgnoreCertificateWarning"] = share["ignore_certificate_warning"]
-        if share.get("proxy_support") is not None:
-            payload["ShareParameters"]["ProxySupport"] = share["proxy_support"]
-        if share.get("proxy_type") is not None:
-            payload["ShareParameters"]["ProxyType"] = share["proxy_type"]
-        if share.get("proxy_port") is not None:
-            payload["ShareParameters"]["ProxyPort"] = share["proxy_port"]
-        if share.get("proxy_server") is not None:
-            payload["ShareParameters"]["ProxyServer"] = share["proxy_server"]
-        if share.get("proxy_username") is not None:
-            payload["ShareParameters"]["ProxyUserName"] = share["proxy_username"]
-        if share.get("proxy_password") is not None:
-            payload["ShareParameters"]["ProxyPassword"] = share["proxy_password"]
-        response = self.invoke_request(IMPORT_PREVIEW, "POST", data=payload)
+        import_preview_uri = _get_scp_import_preview_uri(generation)
+        response = self.invoke_request(import_preview_uri, "POST", data=payload)
         if response.status_code == 202 and job_wait:
             task_uri = response.headers["Location"]
             response = self.wait_for_job_complete(task_uri, job_wait=job_wait)
@@ -396,8 +403,15 @@ class iDRACRedfishAPI(object):
         :param job_wait: True or False decide whether to wait till the job completion.
         :return: json response
         """
-        payload = {"ImportBuffer": import_buffer, "ShareParameters": {"Target": target}, "TimeToWait": time_to_wait}
-        response = self.invoke_request(IMPORT_URI, "POST", data=payload)
+        gen_details = self.get_server_generation
+        generation = gen_details[0]
+        payload = {
+            "ImportBuffer": import_buffer,
+            "ShareParameters": self.form_scp_share_param(target),
+            "TimeToWait": time_to_wait,
+        }
+        import_uri = _get_scp_import_uri(generation)
+        response = self.invoke_request(import_uri, "POST", data=payload)
         if response.status_code == 202 and job_wait:
             task_uri = response.headers["Location"]
             response = self.wait_for_job_complete(task_uri, job_wait=job_wait)
@@ -411,7 +425,8 @@ class iDRACRedfishAPI(object):
         :param job_wait: True or False decide whether to wait till the job completion.
         :return: json response
         """
-        payload = {"ImportBuffer": import_buffer, "ShareParameters": {"Target": target}}
+        payload = {"ImportBuffer": import_buffer,
+                   "ShareParameters": self.form_scp_share_param(target)}
         response = self.invoke_request(IMPORT_PREVIEW, "POST", data=payload)
         if response.status_code == 202 and job_wait:
             task_uri = response.headers["Location"]
@@ -438,6 +453,29 @@ class iDRACRedfishAPI(object):
         """Check if the value is set in REQUESTS_CA_BUNDLE or CURL_CA_BUNDLE or OMAM_CA_BUNDLE or returns None"""
         return os.environ.get("REQUESTS_CA_BUNDLE") or os.environ.get("CURL_CA_BUNDLE") or os.environ.get("OMAM_CA_BUNDLE")
 
+    def validate_idrac10_and_above(self):
+        gen_details = self.get_server_generation
+        hw_model = gen_details[2]
+        return hw_model == 'iDRAC 10'
+
+    def get_job_uri(self):
+        idrac10_or_above = self.validate_idrac10_and_above()
+        if idrac10_or_above:
+            return "/redfish/v1/Managers/iDRAC.Embedded.1/Oem/Dell/Jobs/{job_id}"
+        return "/redfish/v1/Managers/iDRAC.Embedded.1/Jobs/{job_id}"
+
+    def find_ip_address(self, sharename):
+        pattern_ipv4 = r'\b\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}\b'
+        ipv4_addresses = re.findall(pattern_ipv4, sharename)
+        pattern_ipv6 = r'\b(?:[A-Fa-f0-9]{1,4}:){7}[A-Fa-f0-9]{1,4}\b'
+        ipv6_addresses = re.findall(pattern_ipv6, sharename)
+        address = None
+        if ipv4_addresses:
+            address = ipv4_addresses[0]
+        elif ipv6_addresses:
+            address = ipv6_addresses[0]
+        return address
+
 
 class IdracAnsibleModule(AnsibleModule):
     def __init__(self, argument_spec, bypass_checks=False, no_log=False,
