@@ -12,11 +12,10 @@ ANSIBLE_METADATA = {'status': ['preview'],
 DOCUMENTATION = '''
 ---
 module: fmgr_cloud_orchestawstemplate_autoscaleexistingvpc
-short_description: no description
+short_description: Cloud orchest awstemplate autoscale existing vpc
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.2.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -89,27 +91,34 @@ options:
         required: false
         type: dict
         suboptions:
-            custom-asset-container:
+            custom_asset_container:
+                aliases: ['custom-asset-container']
                 type: str
-                description: Deprecated, please rename it to custom_asset_container.
-            custom-asset-directory:
+                description: Custom asset container.
+            custom_asset_directory:
+                aliases: ['custom-asset-directory']
                 type: str
-                description: Deprecated, please rename it to custom_asset_directory.
-            custom-identifier:
+                description: Custom asset directory.
+            custom_identifier:
+                aliases: ['custom-identifier']
                 type: str
-                description: Deprecated, please rename it to custom_identifier.
-            faz-autoscale-admin-password:
+                description: Custom identifier.
+            faz_autoscale_admin_password:
+                aliases: ['faz-autoscale-admin-password']
                 type: raw
-                description: (list) Deprecated, please rename it to faz_autoscale_admin_password.
-            faz-autoscale-admin-username:
+                description: (list) Faz autoscale admin password.
+            faz_autoscale_admin_username:
+                aliases: ['faz-autoscale-admin-username']
                 type: str
-                description: Deprecated, please rename it to faz_autoscale_admin_username.
-            faz-custom-private-ipaddress:
+                description: Faz autoscale admin username.
+            faz_custom_private_ipaddress:
+                aliases: ['faz-custom-private-ipaddress']
                 type: str
-                description: Deprecated, please rename it to faz_custom_private_ipaddress.
-            faz-instance-type:
+                description: Faz custom private ipaddress.
+            faz_instance_type:
+                aliases: ['faz-instance-type']
                 type: str
-                description: Deprecated, please rename it to faz_instance_type.
+                description: Faz instance type.
                 choices:
                     - 'h1.2xlarge'
                     - 'h1.4xlarge'
@@ -122,24 +131,29 @@ options:
                     - 't2.medium'
                     - 't2.large'
                     - 't2.xlarge'
-            faz-integration-options:
+            faz_integration_options:
+                aliases: ['faz-integration-options']
                 type: str
-                description: Deprecated, please rename it to faz_integration_options.
+                description: Faz integration options.
                 choices:
                     - 'no'
                     - 'yes'
-            faz-version:
+            faz_version:
+                aliases: ['faz-version']
                 type: str
-                description: Deprecated, please rename it to faz_version.
-            fgt-admin-cidr:
+                description: Faz version.
+            fgt_admin_cidr:
+                aliases: ['fgt-admin-cidr']
                 type: str
-                description: Deprecated, please rename it to fgt_admin_cidr.
-            fgt-admin-port:
+                description: Fgt admin cidr.
+            fgt_admin_port:
+                aliases: ['fgt-admin-port']
                 type: int
-                description: Deprecated, please rename it to fgt_admin_port.
-            fgt-instance-type:
+                description: Fgt admin port.
+            fgt_instance_type:
+                aliases: ['fgt-instance-type']
                 type: str
-                description: Deprecated, please rename it to fgt_instance_type.
+                description: Fgt instance type.
                 choices:
                     - 't2.small'
                     - 'c5.large'
@@ -147,218 +161,259 @@ options:
                     - 'c5.2xlarge'
                     - 'c5.4xlarge'
                     - 'c5.9xlarge'
-            fgt-psk-secret:
+            fgt_psk_secret:
+                aliases: ['fgt-psk-secret']
                 type: str
-                description: Deprecated, please rename it to fgt_psk_secret.
-            fgtasg-cool-down:
+                description: Fgt psk secret.
+            fgtasg_cool_down:
+                aliases: ['fgtasg-cool-down']
                 type: int
-                description: Deprecated, please rename it to fgtasg_cool_down.
-            fgtasg-desired-capacity-byol:
+                description: Fgtasg cool down.
+            fgtasg_desired_capacity_byol:
+                aliases: ['fgtasg-desired-capacity-byol']
                 type: int
-                description: Deprecated, please rename it to fgtasg_desired_capacity_byol.
-            fgtasg-desired-capacity-payg:
+                description: Fgtasg desired capacity byol.
+            fgtasg_desired_capacity_payg:
+                aliases: ['fgtasg-desired-capacity-payg']
                 type: int
-                description: Deprecated, please rename it to fgtasg_desired_capacity_payg.
-            fgtasg-health-check-grace-period:
+                description: Fgtasg desired capacity payg.
+            fgtasg_health_check_grace_period:
+                aliases: ['fgtasg-health-check-grace-period']
                 type: int
-                description: Deprecated, please rename it to fgtasg_health_check_grace_period.
-            fgtasg-max-size-byol:
+                description: Fgtasg health check grace period.
+            fgtasg_max_size_byol:
+                aliases: ['fgtasg-max-size-byol']
                 type: int
-                description: Deprecated, please rename it to fgtasg_max_size_byol.
-            fgtasg-max-size-payg:
+                description: Fgtasg max size byol.
+            fgtasg_max_size_payg:
+                aliases: ['fgtasg-max-size-payg']
                 type: int
-                description: Deprecated, please rename it to fgtasg_max_size_payg.
-            fgtasg-min-size-byol:
+                description: Fgtasg max size payg.
+            fgtasg_min_size_byol:
+                aliases: ['fgtasg-min-size-byol']
                 type: int
-                description: Deprecated, please rename it to fgtasg_min_size_byol.
-            fgtasg-min-size-payg:
+                description: Fgtasg min size byol.
+            fgtasg_min_size_payg:
+                aliases: ['fgtasg-min-size-payg']
                 type: int
-                description: Deprecated, please rename it to fgtasg_min_size_payg.
-            fgtasg-scale-in-threshold:
+                description: Fgtasg min size payg.
+            fgtasg_scale_in_threshold:
+                aliases: ['fgtasg-scale-in-threshold']
                 type: int
-                description: Deprecated, please rename it to fgtasg_scale_in_threshold.
-            fgtasg-scale-out-threshold:
+                description: Fgtasg scale in threshold.
+            fgtasg_scale_out_threshold:
+                aliases: ['fgtasg-scale-out-threshold']
                 type: int
-                description: Deprecated, please rename it to fgtasg_scale_out_threshold.
-            fos-version:
+                description: Fgtasg scale out threshold.
+            fos_version:
+                aliases: ['fos-version']
                 type: str
-                description: Deprecated, please rename it to fos_version.
-            get-license-grace-period:
+                description: Fos version.
+            get_license_grace_period:
+                aliases: ['get-license-grace-period']
                 type: int
-                description: Deprecated, please rename it to get_license_grace_period.
-            heartbeat-delay-allowance:
+                description: Get license grace period.
+            heartbeat_delay_allowance:
+                aliases: ['heartbeat-delay-allowance']
                 type: int
-                description: Deprecated, please rename it to heartbeat_delay_allowance.
-            heartbeat-interval:
+                description: Heartbeat delay allowance.
+            heartbeat_interval:
+                aliases: ['heartbeat-interval']
                 type: int
-                description: Deprecated, please rename it to heartbeat_interval.
-            heartbeat-loss-count:
+                description: Heartbeat interval.
+            heartbeat_loss_count:
+                aliases: ['heartbeat-loss-count']
                 type: int
-                description: Deprecated, please rename it to heartbeat_loss_count.
-            internal-balancer-dns-name:
+                description: Heartbeat loss count.
+            internal_balancer_dns_name:
+                aliases: ['internal-balancer-dns-name']
                 type: str
-                description: Deprecated, please rename it to internal_balancer_dns_name.
-            internal-balancing-options:
+                description: Internal balancer dns name.
+            internal_balancing_options:
+                aliases: ['internal-balancing-options']
                 type: str
-                description: Deprecated, please rename it to internal_balancing_options.
+                description: Internal balancing options.
                 choices:
                     - 'add a new internal load balancer'
                     - 'use a load balancer specified below'
                     - 'do not need one'
-            internal-target-group-health-check-path:
+            internal_target_group_health_check_path:
+                aliases: ['internal-target-group-health-check-path']
                 type: str
-                description: Deprecated, please rename it to internal_target_group_health_check_path.
-            key-pair-name:
+                description: Internal target group health check path.
+            key_pair_name:
+                aliases: ['key-pair-name']
                 type: str
-                description: Deprecated, please rename it to key_pair_name.
-            lifecycle-hook-timeout:
+                description: Key pair name.
+            lifecycle_hook_timeout:
+                aliases: ['lifecycle-hook-timeout']
                 type: int
-                description: Deprecated, please rename it to lifecycle_hook_timeout.
-            loadbalancing-health-check-threshold:
+                description: Lifecycle hook timeout.
+            loadbalancing_health_check_threshold:
+                aliases: ['loadbalancing-health-check-threshold']
                 type: int
-                description: Deprecated, please rename it to loadbalancing_health_check_threshold.
-            loadbalancing-traffic-port:
+                description: Loadbalancing health check threshold.
+            loadbalancing_traffic_port:
+                aliases: ['loadbalancing-traffic-port']
                 type: int
-                description: Deprecated, please rename it to loadbalancing_traffic_port.
-            loadbalancing-traffic-protocol:
+                description: Loadbalancing traffic port.
+            loadbalancing_traffic_protocol:
+                aliases: ['loadbalancing-traffic-protocol']
                 type: str
-                description: Deprecated, please rename it to loadbalancing_traffic_protocol.
+                description: Loadbalancing traffic protocol.
                 choices:
                     - 'HTTPS'
                     - 'HTTP'
                     - 'TCP'
             name:
                 type: str
-                description: No description.
+                description: Name.
                 required: true
-            notification-email:
+            notification_email:
+                aliases: ['notification-email']
                 type: str
-                description: Deprecated, please rename it to notification_email.
-            primary-election-timeout:
+                description: Notification email.
+            primary_election_timeout:
+                aliases: ['primary-election-timeout']
                 type: int
-                description: Deprecated, please rename it to primary_election_timeout.
-            private-subnet-route-table:
+                description: Primary election timeout.
+            private_subnet_route_table:
+                aliases: ['private-subnet-route-table']
                 type: str
-                description: Deprecated, please rename it to private_subnet_route_table.
-            private-subnet1:
+                description: Private subnet route table.
+            private_subnet1:
+                aliases: ['private-subnet1']
                 type: str
-                description: Deprecated, please rename it to private_subnet1.
-            private-subnet2:
+                description: Private subnet1.
+            private_subnet2:
+                aliases: ['private-subnet2']
                 type: str
-                description: Deprecated, please rename it to private_subnet2.
-            public-subnet1:
+                description: Private subnet2.
+            public_subnet1:
+                aliases: ['public-subnet1']
                 type: str
-                description: Deprecated, please rename it to public_subnet1.
-            public-subnet2:
+                description: Public subnet1.
+            public_subnet2:
+                aliases: ['public-subnet2']
                 type: str
-                description: Deprecated, please rename it to public_subnet2.
-            resource-tag-prefix:
+                description: Public subnet2.
+            resource_tag_prefix:
+                aliases: ['resource-tag-prefix']
                 type: str
-                description: Deprecated, please rename it to resource_tag_prefix.
-            s3-bucket-name:
+                description: Resource tag prefix.
+            s3_bucket_name:
+                aliases: ['s3-bucket-name']
                 type: str
-                description: Deprecated, please rename it to s3_bucket_name.
-            s3-key-prefix:
+                description: S3 bucket name.
+            s3_key_prefix:
+                aliases: ['s3-key-prefix']
                 type: str
-                description: Deprecated, please rename it to s3_key_prefix.
-            sync-recovery-count:
+                description: S3 key prefix.
+            sync_recovery_count:
+                aliases: ['sync-recovery-count']
                 type: int
-                description: Deprecated, please rename it to sync_recovery_count.
-            terminate-unhealthy-vm:
+                description: Sync recovery count.
+            terminate_unhealthy_vm:
+                aliases: ['terminate-unhealthy-vm']
                 type: str
-                description: Deprecated, please rename it to terminate_unhealthy_vm.
+                description: Terminate unhealthy vm.
                 choices:
                     - 'no'
                     - 'yes'
-            use-custom-asset-location:
+            use_custom_asset_location:
+                aliases: ['use-custom-asset-location']
                 type: str
-                description: Deprecated, please rename it to use_custom_asset_location.
+                description: Use custom asset location.
                 choices:
                     - 'no'
                     - 'yes'
-            vpc-cidr:
+            vpc_cidr:
+                aliases: ['vpc-cidr']
                 type: str
-                description: Deprecated, please rename it to vpc_cidr.
-            vpc-endpoint-id:
+                description: Vpc cidr.
+            vpc_endpoint_id:
+                aliases: ['vpc-endpoint-id']
                 type: str
-                description: Deprecated, please rename it to vpc_endpoint_id.
-            vpc-id:
+                description: Vpc endpoint id.
+            vpc_id:
+                aliases: ['vpc-id']
                 type: str
-                description: Deprecated, please rename it to vpc_id.
+                description: Vpc id.
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
     ansible_httpapi_port: 443
   tasks:
-    - name: No description
+    - name: Cloud orchest awstemplate autoscale existing vpc
       fortinet.fortimanager.fmgr_cloud_orchestawstemplate_autoscaleexistingvpc:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         cloud_orchestawstemplate_autoscaleexistingvpc:
-          custom_asset_container: <string>
-          custom_asset_directory: <string>
-          custom_identifier: <string>
-          faz_autoscale_admin_password: <list or string>
-          faz_autoscale_admin_username: <string>
-          faz_custom_private_ipaddress: <string>
-          faz_instance_type: <value in [h1.2xlarge, h1.4xlarge, h1.8xlarge, ...]>
-          faz_integration_options: <value in [no, yes]>
-          faz_version: <string>
-          fgt_admin_cidr: <string>
-          fgt_admin_port: <integer>
-          fgt_instance_type: <value in [t2.small, c5.large, c5.xlarge, ...]>
-          fgt_psk_secret: <string>
-          fgtasg_cool_down: <integer>
-          fgtasg_desired_capacity_byol: <integer>
-          fgtasg_desired_capacity_payg: <integer>
-          fgtasg_health_check_grace_period: <integer>
-          fgtasg_max_size_byol: <integer>
-          fgtasg_max_size_payg: <integer>
-          fgtasg_min_size_byol: <integer>
-          fgtasg_min_size_payg: <integer>
-          fgtasg_scale_in_threshold: <integer>
-          fgtasg_scale_out_threshold: <integer>
-          fos_version: <string>
-          get_license_grace_period: <integer>
-          heartbeat_delay_allowance: <integer>
-          heartbeat_interval: <integer>
-          heartbeat_loss_count: <integer>
-          internal_balancer_dns_name: <string>
-          internal_balancing_options: <value in [add a new internal load balancer, use a load balancer specified below, do not need one]>
-          internal_target_group_health_check_path: <string>
-          key_pair_name: <string>
-          lifecycle_hook_timeout: <integer>
-          loadbalancing_health_check_threshold: <integer>
-          loadbalancing_traffic_port: <integer>
-          loadbalancing_traffic_protocol: <value in [HTTPS, HTTP, TCP]>
-          name: <string>
-          notification_email: <string>
-          primary_election_timeout: <integer>
-          private_subnet_route_table: <string>
-          private_subnet1: <string>
-          private_subnet2: <string>
-          public_subnet1: <string>
-          public_subnet2: <string>
-          resource_tag_prefix: <string>
-          s3_bucket_name: <string>
-          s3_key_prefix: <string>
-          sync_recovery_count: <integer>
-          terminate_unhealthy_vm: <value in [no, yes]>
-          use_custom_asset_location: <value in [no, yes]>
-          vpc_cidr: <string>
-          vpc_endpoint_id: <string>
-          vpc_id: <string>
+          name: "your value" # Required variable, string
+          # custom_asset_container: <string>
+          # custom_asset_directory: <string>
+          # custom_identifier: <string>
+          # faz_autoscale_admin_password: <list or string>
+          # faz_autoscale_admin_username: <string>
+          # faz_custom_private_ipaddress: <string>
+          # faz_instance_type: <value in [h1.2xlarge, h1.4xlarge, h1.8xlarge, ...]>
+          # faz_integration_options: <value in [no, yes]>
+          # faz_version: <string>
+          # fgt_admin_cidr: <string>
+          # fgt_admin_port: <integer>
+          # fgt_instance_type: <value in [t2.small, c5.large, c5.xlarge, ...]>
+          # fgt_psk_secret: <string>
+          # fgtasg_cool_down: <integer>
+          # fgtasg_desired_capacity_byol: <integer>
+          # fgtasg_desired_capacity_payg: <integer>
+          # fgtasg_health_check_grace_period: <integer>
+          # fgtasg_max_size_byol: <integer>
+          # fgtasg_max_size_payg: <integer>
+          # fgtasg_min_size_byol: <integer>
+          # fgtasg_min_size_payg: <integer>
+          # fgtasg_scale_in_threshold: <integer>
+          # fgtasg_scale_out_threshold: <integer>
+          # fos_version: <string>
+          # get_license_grace_period: <integer>
+          # heartbeat_delay_allowance: <integer>
+          # heartbeat_interval: <integer>
+          # heartbeat_loss_count: <integer>
+          # internal_balancer_dns_name: <string>
+          # internal_balancing_options: <value in [add a new internal load balancer, use a load balancer specified below, do not need one]>
+          # internal_target_group_health_check_path: <string>
+          # key_pair_name: <string>
+          # lifecycle_hook_timeout: <integer>
+          # loadbalancing_health_check_threshold: <integer>
+          # loadbalancing_traffic_port: <integer>
+          # loadbalancing_traffic_protocol: <value in [HTTPS, HTTP, TCP]>
+          # notification_email: <string>
+          # primary_election_timeout: <integer>
+          # private_subnet_route_table: <string>
+          # private_subnet1: <string>
+          # private_subnet2: <string>
+          # public_subnet1: <string>
+          # public_subnet2: <string>
+          # resource_tag_prefix: <string>
+          # s3_bucket_name: <string>
+          # s3_key_prefix: <string>
+          # sync_recovery_count: <integer>
+          # terminate_unhealthy_vm: <value in [no, yes]>
+          # use_custom_asset_location: <value in [no, yes]>
+          # vpc_cidr: <string>
+          # vpc_endpoint_id: <string>
+          # vpc_id: <string>
 '''
 
 RETURN = '''
@@ -402,27 +457,20 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/cloud/orchest-awstemplate/autoscale-existing-vpc',
         '/pm/config/global/obj/cloud/orchest-awstemplate/autoscale-existing-vpc'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/cloud/orchest-awstemplate/autoscale-existing-vpc/{autoscale-existing-vpc}',
-        '/pm/config/global/obj/cloud/orchest-awstemplate/autoscale-existing-vpc/{autoscale-existing-vpc}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'cloud_orchestawstemplate_autoscaleexistingvpc': {
             'type': 'dict',
             'v_range': [['7.4.0', '']],
@@ -496,7 +544,6 @@ def main():
                 'vpc-endpoint-id': {'v_range': [['7.4.0', '']], 'type': 'str'},
                 'vpc-id': {'v_range': [['7.4.0', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -505,17 +552,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'cloud_orchestawstemplate_autoscaleexistingvpc'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
