@@ -12,11 +12,10 @@ ANSIBLE_METADATA = {'status': ['preview'],
 DOCUMENTATION = '''
 ---
 module: fmgr_devprof_device_profile_fortianalyzer
-short_description: no description
+short_description: System template device profile fortianalyzer
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "1.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -84,48 +83,52 @@ options:
         required: false
         type: dict
         suboptions:
-            managed-sn:
+            managed_sn:
+                aliases: ['managed-sn']
                 type: str
-                description: Deprecated, please rename it to managed_sn.
+                description: Managed sn.
             target:
                 type: str
-                description: No description.
+                description: Target.
                 choices:
                     - 'none'
                     - 'this-fmg'
                     - 'managed'
                     - 'others'
-            target-ip:
+            target_ip:
+                aliases: ['target-ip']
                 type: str
-                description: Deprecated, please rename it to target_ip.
-            target-sn:
+                description: Target ip.
+            target_sn:
+                aliases: ['target-sn']
                 type: raw
-                description: (list) Deprecated, please rename it to target_sn.
+                description: (list) Target sn.
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
     ansible_httpapi_port: 443
   tasks:
-    - name: No description
+    - name: System template device profile fortianalyzer
       fortinet.fortimanager.fmgr_devprof_device_profile_fortianalyzer:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         devprof: <your own value>
         devprof_device_profile_fortianalyzer:
-          managed_sn: <string>
-          target: <value in [none, this-fmg, managed, ...]>
-          target_ip: <string>
-          target_sn: <list or string>
+          # managed_sn: <string>
+          # target: <value in [none, this-fmg, managed, ...]>
+          # target_ip: <string>
+          # target_sn: <list or string>
 '''
 
 RETURN = '''
@@ -169,21 +172,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/devprof/{devprof}/device/profile/fortianalyzer'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/devprof/{devprof}/device/profile/fortianalyzer/{fortianalyzer}'
-    ]
-
     url_params = ['adom', 'devprof']
     module_primary_key = None
     module_arg_spec = {
@@ -198,7 +194,6 @@ def main():
                 'target-ip': {'type': 'str'},
                 'target-sn': {'type': 'raw'}
             }
-
         }
     }
 
@@ -207,17 +202,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'devprof_device_profile_fortianalyzer'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
