@@ -16,7 +16,6 @@ short_description: Extender controller sim profile
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.1.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -221,6 +223,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -229,39 +232,39 @@ EXAMPLES = '''
     - name: Extender controller sim profile
       fortinet.fortimanager.fmgr_extendercontroller_simprofile:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         extendercontroller_simprofile:
-          auto_switch_profile:
-            dataplan: <value in [disable, enable]>
-            disconnect: <value in [disable, enable]>
-            disconnect_period: <integer>
-            disconnect_threshold: <integer>
-            signal: <value in [disable, enable]>
-            status: <value in [disable, enable]>
-            switch_back:
-              - "time"
-              - "timer"
-            switch_back_time: <string>
-            switch_back_timer: <integer>
-          conn_status: <integer>
-          default_sim: <value in [sim1, sim2, carrier, ...]>
-          description: <string>
-          gps: <value in [disable, enable]>
-          modem_id: <integer>
-          name: <string>
-          preferred_carrier: <string>
-          redundant_intf: <string>
-          redundant_mode: <value in [disable, enable]>
-          sim1_pin: <value in [disable, enable]>
-          sim1_pin_code: <list or string>
-          sim2_pin: <value in [disable, enable]>
-          sim2_pin_code: <list or string>
-          status: <value in [disable, enable]>
+          name: "your value" # Required variable, string
+          # auto_switch_profile:
+          #   dataplan: <value in [disable, enable]>
+          #   disconnect: <value in [disable, enable]>
+          #   disconnect_period: <integer>
+          #   disconnect_threshold: <integer>
+          #   signal: <value in [disable, enable]>
+          #   status: <value in [disable, enable]>
+          #   switch_back:
+          #     - "time"
+          #     - "timer"
+          #   switch_back_time: <string>
+          #   switch_back_timer: <integer>
+          # conn_status: <integer>
+          # default_sim: <value in [sim1, sim2, carrier, ...]>
+          # description: <string>
+          # gps: <value in [disable, enable]>
+          # modem_id: <integer>
+          # preferred_carrier: <string>
+          # redundant_intf: <string>
+          # redundant_mode: <value in [disable, enable]>
+          # sim1_pin: <value in [disable, enable]>
+          # sim1_pin_code: <list or string>
+          # sim2_pin: <value in [disable, enable]>
+          # sim2_pin_code: <list or string>
+          # status: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -318,6 +321,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'extendercontroller_simprofile': {
             'type': 'dict',
             'v_range': [['6.4.4', '']],
