@@ -16,7 +16,6 @@ short_description: FortiExtender cellular SMS notification configuration.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.2.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -64,6 +63,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -88,38 +90,45 @@ options:
         suboptions:
             alert:
                 type: dict
-                description: No description.
+                description: Alert.
                 suboptions:
-                    data-exhausted:
+                    data_exhausted:
+                        aliases: ['data-exhausted']
                         type: str
-                        description: Deprecated, please rename it to data_exhausted. Display string when data exhausted.
-                    fgt-backup-mode-switch:
+                        description: Display string when data exhausted.
+                    fgt_backup_mode_switch:
+                        aliases: ['fgt-backup-mode-switch']
                         type: str
-                        description: Deprecated, please rename it to fgt_backup_mode_switch. Display string when FortiGate backup mode switched.
-                    low-signal-strength:
+                        description: Display string when FortiGate backup mode switched.
+                    low_signal_strength:
+                        aliases: ['low-signal-strength']
                         type: str
-                        description: Deprecated, please rename it to low_signal_strength. Display string when signal strength is low.
-                    mode-switch:
+                        description: Display string when signal strength is low.
+                    mode_switch:
+                        aliases: ['mode-switch']
                         type: str
-                        description: Deprecated, please rename it to mode_switch. Display string when mode is switched.
-                    os-image-fallback:
+                        description: Display string when mode is switched.
+                    os_image_fallback:
+                        aliases: ['os-image-fallback']
                         type: str
-                        description: Deprecated, please rename it to os_image_fallback. Display string when falling back to a previous OS image.
-                    session-disconnect:
+                        description: Display string when falling back to a previous OS image.
+                    session_disconnect:
+                        aliases: ['session-disconnect']
                         type: str
-                        description: Deprecated, please rename it to session_disconnect. Display string when session disconnected.
-                    system-reboot:
+                        description: Display string when session disconnected.
+                    system_reboot:
+                        aliases: ['system-reboot']
                         type: str
-                        description: Deprecated, please rename it to system_reboot. Display string when system rebooted.
+                        description: Display string when system rebooted.
             receiver:
                 type: list
                 elements: dict
-                description: No description.
+                description: Receiver.
                 suboptions:
                     alert:
                         type: list
                         elements: str
-                        description: No description.
+                        description: Alert multi-options.
                         choices:
                             - 'system-reboot'
                             - 'data-exhausted'
@@ -131,9 +140,10 @@ options:
                     name:
                         type: str
                         description: FortiExtender SMS notification receiver name.
-                    phone-number:
+                    phone_number:
+                        aliases: ['phone-number']
                         type: str
-                        description: Deprecated, please rename it to phone_number. Receiver phone number.
+                        description: Receiver phone number.
                     status:
                         type: str
                         description: SMS notification receiver status.
@@ -152,6 +162,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -160,35 +171,34 @@ EXAMPLES = '''
     - name: FortiExtender cellular SMS notification configuration.
       fortinet.fortimanager.fmgr_extensioncontroller_extenderprofile_cellular_smsnotification:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         extender_profile: <your own value>
         extensioncontroller_extenderprofile_cellular_smsnotification:
-          alert:
-            data_exhausted: <string>
-            fgt_backup_mode_switch: <string>
-            low_signal_strength: <string>
-            mode_switch: <string>
-            os_image_fallback: <string>
-            session_disconnect: <string>
-            system_reboot: <string>
-          receiver:
-            -
-              alert:
-                - system-reboot
-                - data-exhausted
-                - session-disconnect
-                - low-signal-strength
-                - mode-switch
-                - os-image-fallback
-                - fgt-backup-mode-switch
-              name: <string>
-              phone_number: <string>
-              status: <value in [disable, enable]>
-          status: <value in [disable, enable]>
+          # alert:
+          #   data_exhausted: <string>
+          #   fgt_backup_mode_switch: <string>
+          #   low_signal_strength: <string>
+          #   mode_switch: <string>
+          #   os_image_fallback: <string>
+          #   session_disconnect: <string>
+          #   system_reboot: <string>
+          # receiver:
+          #   - alert:
+          #       - "system-reboot"
+          #       - "data-exhausted"
+          #       - "session-disconnect"
+          #       - "low-signal-strength"
+          #       - "mode-switch"
+          #       - "os-image-fallback"
+          #       - "fgt-backup-mode-switch"
+          #     name: <string>
+          #     phone_number: <string>
+          #     status: <value in [disable, enable]>
+          # status: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -232,34 +242,28 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/extension-controller/extender-profile/{extender-profile}/cellular/sms-notification',
         '/pm/config/global/obj/extension-controller/extender-profile/{extender-profile}/cellular/sms-notification'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/extension-controller/extender-profile/{extender-profile}/cellular/sms-notification/{sms-notification}',
-        '/pm/config/global/obj/extension-controller/extender-profile/{extender-profile}/cellular/sms-notification/{sms-notification}'
-    ]
-
     url_params = ['adom', 'extender-profile']
     module_primary_key = None
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'extender-profile': {'type': 'str', 'api_name': 'extender_profile'},
         'extender_profile': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'extensioncontroller_extenderprofile_cellular_smsnotification': {
             'type': 'dict',
             'v_range': [['7.2.1', '']],
             'options': {
                 'alert': {
+                    'v_range': [['7.2.1', '']],
                     'type': 'dict',
                     'options': {
                         'data-exhausted': {'v_range': [['7.2.1', '']], 'type': 'str'},
@@ -292,7 +296,6 @@ def main():
                 },
                 'status': {'v_range': [['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -301,17 +304,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'extensioncontroller_extenderprofile_cellular_smsnotification'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
