@@ -16,7 +16,6 @@ short_description: Enable/disable access to the public FortiGuard.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -99,6 +98,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -107,13 +107,13 @@ EXAMPLES = '''
     - name: Enable/disable access to the public FortiGuard.
       fortinet.fortimanager.fmgr_fmupdate_publicnetwork:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         fmupdate_publicnetwork:
-          status: <value in [disable, enable]>
-          update_server_location: <value in [global, usa, eu]>
+          # status: <value in [disable, enable]>
+          # update_server_location: <value in [global, usa, eu]>
 '''
 
 RETURN = '''
