@@ -16,7 +16,6 @@ short_description: Configure shaping policies.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -89,185 +91,232 @@ options:
         required: false
         type: dict
         suboptions:
-            app-category:
+            app_category:
+                aliases: ['app-category']
                 type: raw
-                description: (list or str) Deprecated, please rename it to app_category.
-            app-group:
+                description: (list or str) App category.
+            app_group:
+                aliases: ['app-group']
                 type: raw
-                description: (list or str) Deprecated, please rename it to app_group.
+                description: (list or str) App group.
             application:
                 type: raw
-                description: (list) No description.
-            class-id:
+                description: (list) Application.
+            class_id:
+                aliases: ['class-id']
                 type: raw
-                description: (int or str) Deprecated, please rename it to class_id.
+                description: (int or str) Class id.
             comment:
                 type: str
-                description: No description.
-            diffserv-forward:
+                description: Comment.
+            diffserv_forward:
+                aliases: ['diffserv-forward']
                 type: str
-                description: Deprecated, please rename it to diffserv_forward.
+                description: Diffserv forward.
                 choices:
                     - 'disable'
                     - 'enable'
-            diffserv-reverse:
+            diffserv_reverse:
+                aliases: ['diffserv-reverse']
                 type: str
-                description: Deprecated, please rename it to diffserv_reverse.
+                description: Diffserv reverse.
                 choices:
                     - 'disable'
                     - 'enable'
-            diffservcode-forward:
+            diffservcode_forward:
+                aliases: ['diffservcode-forward']
                 type: str
-                description: Deprecated, please rename it to diffservcode_forward.
-            diffservcode-rev:
+                description: Diffservcode forward.
+            diffservcode_rev:
+                aliases: ['diffservcode-rev']
                 type: str
-                description: Deprecated, please rename it to diffservcode_rev.
+                description: Diffservcode rev.
             dstaddr:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Dstaddr.
             dstaddr6:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Dstaddr6.
             dstintf:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Dstintf.
             groups:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Groups.
             id:
                 type: int
-                description: No description.
+                description: Id.
                 required: true
-            internet-service:
+            internet_service:
+                aliases: ['internet-service']
                 type: str
-                description: Deprecated, please rename it to internet_service.
+                description: Internet service.
                 choices:
                     - 'disable'
                     - 'enable'
-            internet-service-custom:
+            internet_service_custom:
+                aliases: ['internet-service-custom']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_custom.
-            internet-service-custom-group:
+                description: (list or str) Internet service custom.
+            internet_service_custom_group:
+                aliases: ['internet-service-custom-group']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_custom_group.
-            internet-service-group:
+                description: (list or str) Internet service custom group.
+            internet_service_group:
+                aliases: ['internet-service-group']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_group.
-            internet-service-id:
+                description: (list or str) Internet service group.
+            internet_service_id:
+                aliases: ['internet-service-id']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_id.
-            internet-service-src:
+                description: (list or str) Internet service id.
+            internet_service_src:
+                aliases: ['internet-service-src']
                 type: str
-                description: Deprecated, please rename it to internet_service_src.
+                description: Internet service src.
                 choices:
                     - 'disable'
                     - 'enable'
-            internet-service-src-custom:
+            internet_service_src_custom:
+                aliases: ['internet-service-src-custom']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_src_custom.
-            internet-service-src-custom-group:
+                description: (list or str) Internet service src custom.
+            internet_service_src_custom_group:
+                aliases: ['internet-service-src-custom-group']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_src_custom_group.
-            internet-service-src-group:
+                description: (list or str) Internet service src custom group.
+            internet_service_src_group:
+                aliases: ['internet-service-src-group']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_src_group.
-            internet-service-src-id:
+                description: (list or str) Internet service src group.
+            internet_service_src_id:
+                aliases: ['internet-service-src-id']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_src_id.
-            ip-version:
+                description: (list or str) Internet service src id.
+            ip_version:
+                aliases: ['ip-version']
                 type: str
-                description: Deprecated, please rename it to ip_version.
+                description: Ip version.
                 choices:
                     - '4'
                     - '6'
-            per-ip-shaper:
+            per_ip_shaper:
+                aliases: ['per-ip-shaper']
                 type: str
-                description: Deprecated, please rename it to per_ip_shaper.
+                description: Per ip shaper.
             schedule:
                 type: str
-                description: No description.
+                description: Schedule.
             service:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Service.
             srcaddr:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Srcaddr.
             srcaddr6:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Srcaddr6.
             srcintf:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Srcintf.
             status:
                 type: str
-                description: No description.
+                description: Status.
                 choices:
                     - 'disable'
                     - 'enable'
             tos:
                 type: str
-                description: No description.
-            tos-mask:
+                description: Tos.
+            tos_mask:
+                aliases: ['tos-mask']
                 type: str
-                description: Deprecated, please rename it to tos_mask.
-            tos-negate:
+                description: Tos mask.
+            tos_negate:
+                aliases: ['tos-negate']
                 type: str
-                description: Deprecated, please rename it to tos_negate.
+                description: Tos negate.
                 choices:
                     - 'disable'
                     - 'enable'
-            traffic-shaper:
+            traffic_shaper:
+                aliases: ['traffic-shaper']
                 type: str
-                description: Deprecated, please rename it to traffic_shaper.
-            traffic-shaper-reverse:
+                description: Traffic shaper.
+            traffic_shaper_reverse:
+                aliases: ['traffic-shaper-reverse']
                 type: str
-                description: Deprecated, please rename it to traffic_shaper_reverse.
-            url-category:
+                description: Traffic shaper reverse.
+            url_category:
+                aliases: ['url-category']
                 type: raw
-                description: (list or str) Deprecated, please rename it to url_category.
+                description: (list or str) Url category.
             users:
                 type: raw
-                description: (list or str) No description.
+                description: (list or str) Users.
             uuid:
                 type: str
-                description: No description.
-            internet-service-name:
+                description: Uuid.
+            internet_service_name:
+                aliases: ['internet-service-name']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_name.
-            internet-service-src-name:
+                description: (list or str) Internet service name.
+            internet_service_src_name:
+                aliases: ['internet-service-src-name']
                 type: raw
-                description: (list or str) Deprecated, please rename it to internet_service_src_name.
-            class-id-reverse:
+                description: (list or str) Internet service src name.
+            class_id_reverse:
+                aliases: ['class-id-reverse']
                 type: int
-                description: Deprecated, please rename it to class_id_reverse.
-            service-type:
+                description: Class id reverse.
+            service_type:
+                aliases: ['service-type']
                 type: str
-                description: Deprecated, please rename it to service_type.
+                description: Service type.
                 choices:
                     - 'service'
                     - 'internet-service'
-            uuid-idx:
+            uuid_idx:
+                aliases: ['uuid-idx']
                 type: int
-                description: Deprecated, please rename it to uuid_idx.
+                description: Uuid idx.
             cos:
                 type: str
                 description: VLAN CoS bit pattern.
-            cos-mask:
+            cos_mask:
+                aliases: ['cos-mask']
                 type: str
-                description: Deprecated, please rename it to cos_mask. VLAN CoS evaluated bits.
-            traffic-type:
+                description: VLAN CoS evaluated bits.
+            traffic_type:
+                aliases: ['traffic-type']
                 type: str
-                description: Deprecated, please rename it to traffic_type. Traffic type.
+                description: Traffic type.
                 choices:
                     - 'forwarding'
                     - 'local-in'
                     - 'local-out'
+            http_response_match:
+                aliases: ['http-response-match']
+                type: str
+                description: Http response match.
+                choices:
+                    - 'disable'
+                    - 'enable'
+            internet_service_fortiguard:
+                aliases: ['internet-service-fortiguard']
+                type: raw
+                description: (list) FortiGuard Internet Service name.
+            internet_service_src_fortiguard:
+                aliases: ['internet-service-src-fortiguard']
+                type: raw
+                description: (list) FortiGuard Internet Service source name.
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -276,61 +325,64 @@ EXAMPLES = '''
     - name: Configure shaping policies.
       fortinet.fortimanager.fmgr_pkg_footer_shapingpolicy:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         pkg: <your own value>
         state: present # <value in [present, absent]>
         pkg_footer_shapingpolicy:
-          app_category: <list or string>
-          app_group: <list or string>
-          application: <list or integer>
-          class_id: <integer or string>
-          comment: <string>
-          diffserv_forward: <value in [disable, enable]>
-          diffserv_reverse: <value in [disable, enable]>
-          diffservcode_forward: <string>
-          diffservcode_rev: <string>
-          dstaddr: <list or string>
-          dstaddr6: <list or string>
-          dstintf: <list or string>
-          groups: <list or string>
-          id: <integer>
-          internet_service: <value in [disable, enable]>
-          internet_service_custom: <list or string>
-          internet_service_custom_group: <list or string>
-          internet_service_group: <list or string>
-          internet_service_id: <list or string>
-          internet_service_src: <value in [disable, enable]>
-          internet_service_src_custom: <list or string>
-          internet_service_src_custom_group: <list or string>
-          internet_service_src_group: <list or string>
-          internet_service_src_id: <list or string>
-          ip_version: <value in [4, 6]>
-          per_ip_shaper: <string>
-          schedule: <string>
-          service: <list or string>
-          srcaddr: <list or string>
-          srcaddr6: <list or string>
-          srcintf: <list or string>
-          status: <value in [disable, enable]>
-          tos: <string>
-          tos_mask: <string>
-          tos_negate: <value in [disable, enable]>
-          traffic_shaper: <string>
-          traffic_shaper_reverse: <string>
-          url_category: <list or string>
-          users: <list or string>
-          uuid: <string>
-          internet_service_name: <list or string>
-          internet_service_src_name: <list or string>
-          class_id_reverse: <integer>
-          service_type: <value in [service, internet-service]>
-          uuid_idx: <integer>
-          cos: <string>
-          cos_mask: <string>
-          traffic_type: <value in [forwarding, local-in, local-out]>
+          id: 0 # Required variable, integer
+          # app_category: <list or string>
+          # app_group: <list or string>
+          # application: <list or integer>
+          # class_id: <integer or string>
+          # comment: <string>
+          # diffserv_forward: <value in [disable, enable]>
+          # diffserv_reverse: <value in [disable, enable]>
+          # diffservcode_forward: <string>
+          # diffservcode_rev: <string>
+          # dstaddr: <list or string>
+          # dstaddr6: <list or string>
+          # dstintf: <list or string>
+          # groups: <list or string>
+          # internet_service: <value in [disable, enable]>
+          # internet_service_custom: <list or string>
+          # internet_service_custom_group: <list or string>
+          # internet_service_group: <list or string>
+          # internet_service_id: <list or string>
+          # internet_service_src: <value in [disable, enable]>
+          # internet_service_src_custom: <list or string>
+          # internet_service_src_custom_group: <list or string>
+          # internet_service_src_group: <list or string>
+          # internet_service_src_id: <list or string>
+          # ip_version: <value in [4, 6]>
+          # per_ip_shaper: <string>
+          # schedule: <string>
+          # service: <list or string>
+          # srcaddr: <list or string>
+          # srcaddr6: <list or string>
+          # srcintf: <list or string>
+          # status: <value in [disable, enable]>
+          # tos: <string>
+          # tos_mask: <string>
+          # tos_negate: <value in [disable, enable]>
+          # traffic_shaper: <string>
+          # traffic_shaper_reverse: <string>
+          # url_category: <list or string>
+          # users: <list or string>
+          # uuid: <string>
+          # internet_service_name: <list or string>
+          # internet_service_src_name: <list or string>
+          # class_id_reverse: <integer>
+          # service_type: <value in [service, internet-service]>
+          # uuid_idx: <integer>
+          # cos: <string>
+          # cos_mask: <string>
+          # traffic_type: <value in [forwarding, local-in, local-out]>
+          # http_response_match: <value in [disable, enable]>
+          # internet_service_fortiguard: <list or string>
+          # internet_service_src_fortiguard: <list or string>
 '''
 
 RETURN = '''
@@ -374,25 +426,19 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/global/pkg/{pkg}/global/footer/shaping-policy'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/global/pkg/{pkg}/global/footer/shaping-policy/{shaping-policy}'
-    ]
-
     url_params = ['pkg']
     module_primary_key = 'id'
     module_arg_spec = {
         'pkg': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'pkg_footer_shapingpolicy': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -444,9 +490,11 @@ def main():
                 'uuid-idx': {'v_range': [['7.2.1', '']], 'type': 'int'},
                 'cos': {'v_range': [['7.4.0', '']], 'type': 'str'},
                 'cos-mask': {'v_range': [['7.4.0', '']], 'type': 'str'},
-                'traffic-type': {'v_range': [['7.4.0', '']], 'choices': ['forwarding', 'local-in', 'local-out'], 'type': 'str'}
+                'traffic-type': {'v_range': [['7.4.0', '']], 'choices': ['forwarding', 'local-in', 'local-out'], 'type': 'str'},
+                'http-response-match': {'v_range': [['7.4.7', '7.4.8'], ['7.6.4', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'internet-service-fortiguard': {'v_range': [['7.6.4', '']], 'type': 'raw'},
+                'internet-service-src-fortiguard': {'v_range': [['7.6.4', '']], 'type': 'raw'}
             }
-
         }
     }
 
@@ -463,17 +511,15 @@ def main():
 
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'pkg_footer_shapingpolicy'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
