@@ -16,7 +16,6 @@ short_description: Generate and sign certificate on the target device.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -92,6 +91,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -100,17 +100,16 @@ EXAMPLES = '''
     - name: Generate and sign certificate on the target device.
       fortinet.fortimanager.fmgr_securityconsole_sign_certificate_template:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         securityconsole_sign_certificate_template:
-          adom: <string>
-          scope:
-            -
-              name: <string>
-              vdom: <string>
-          template: <string>
+          # adom: <string>
+          # scope:
+          #   - name: <string>
+          #     vdom: <string>
+          # template: <string>
 '''
 
 RETURN = '''
