@@ -16,7 +16,6 @@ short_description: Excluding admin domain.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -89,9 +88,10 @@ options:
         required: false
         type: dict
         suboptions:
-            adom-name:
+            adom_name:
+                aliases: ['adom-name']
                 type: str
-                description: Deprecated, please rename it to adom_name. Admin domain names.
+                description: Admin domain names.
                 required: true
 '''
 
@@ -99,6 +99,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -107,14 +108,14 @@ EXAMPLES = '''
     - name: Excluding admin domain.
       fortinet.fortimanager.fmgr_system_admin_user_adomexclude:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         user: <your own value>
         state: present # <value in [present, absent]>
         system_admin_user_adomexclude:
-          adom_name: <string>
+          adom_name: "your value" # Required variable, string
 '''
 
 RETURN = '''
@@ -158,21 +159,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/admin/user/{user}/adom-exclude'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/admin/user/{user}/adom-exclude/{adom-exclude}'
-    ]
-
     url_params = ['user']
     module_primary_key = 'adom-name'
     module_arg_spec = {
@@ -181,7 +175,6 @@ def main():
             'type': 'dict',
             'v_range': [['6.0.0', '7.0.2']],
             'options': {'adom-name': {'v_range': [['6.0.0', '7.0.2']], 'required': True, 'type': 'str'}}
-
         }
     }
 
@@ -190,14 +183,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_admin_user_adomexclude'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
