@@ -16,7 +16,6 @@ short_description: Add this device to a Security Fabric or set up a new Security
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.3.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -76,20 +75,20 @@ options:
         required: false
         type: dict
         suboptions:
-            accept-auth-by-cert:
+            accept_auth_by_cert:
+                aliases: ['accept-auth-by-cert']
                 type: str
                 description:
-                    - Deprecated, please rename it to accept_auth_by_cert.
                     - Accept connections with unknown certificates and ask admin for approval.
                     - disable - Do not accept SSL connections with unknown certificates.
                     - enable - Accept SSL connections without automatic certificate verification.
                 choices:
                     - 'disable'
                     - 'enable'
-            authorization-request-type:
+            authorization_request_type:
+                aliases: ['authorization-request-type']
                 type: str
                 description:
-                    - Deprecated, please rename it to authorization_request_type.
                     - Authorization request type.
                     - certificate - Request verification by certificate.
                     - serial - Request verification by serial number.
@@ -99,41 +98,43 @@ options:
             certificate:
                 type: str
                 description: Certificate.
-            configuration-sync:
+            configuration_sync:
+                aliases: ['configuration-sync']
                 type: str
                 description:
-                    - Deprecated, please rename it to configuration_sync.
                     - Configuration sync mode.
                     - default - Synchronize configuration for IPAM, FortiAnalyzer, FortiSandbox, and Central Management to root node.
                     - local - Do not synchronize configuration with root node.
                 choices:
                     - 'default'
                     - 'local'
-            downstream-access:
+            downstream_access:
+                aliases: ['downstream-access']
                 type: str
                 description:
-                    - Deprecated, please rename it to downstream_access.
                     - Enable/disable downstream device access to this device&apos;s configuration and data.
                     - disable - Disable downstream device access to this device&apos;s configuration and data.
                     - enable - Enable downstream device access to this device&apos;s configuration and data.
                 choices:
                     - 'disable'
                     - 'enable'
-            downstream-accprofile:
+            downstream_accprofile:
+                aliases: ['downstream-accprofile']
                 type: str
-                description: Deprecated, please rename it to downstream_accprofile. Default access profile for requests from downstream devices.
-            fabric-connector:
+                description: Default access profile for requests from downstream devices.
+            fabric_connector:
+                aliases: ['fabric-connector']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to fabric_connector.
+                description: Fabric connector.
                 suboptions:
                     accprofile:
                         type: str
                         description: Override access profile.
-                    configuration-write-access:
+                    configuration_write_access:
+                        aliases: ['configuration-write-access']
                         type: str
                         description:
-                            - Deprecated, please rename it to configuration_write_access.
                             - Enable/disable downstream device write access to configuration.
                             - disable - Disable downstream device write access to configuration.
                             - enable - Enable downstream device write access to configuration.
@@ -143,70 +144,76 @@ options:
                     serial:
                         type: str
                         description: Serial.
-            fabric-object-unification:
+            fabric_object_unification:
+                aliases: ['fabric-object-unification']
                 type: str
                 description:
-                    - Deprecated, please rename it to fabric_object_unification.
                     - Fabric CMDB Object Unification.
                     - local - Global CMDB objects will not be synchronized to and from this device.
                     - default - Global CMDB objects will be synchronized in Security Fabric.
                 choices:
                     - 'local'
                     - 'default'
-            fabric-workers:
+            fabric_workers:
+                aliases: ['fabric-workers']
                 type: int
-                description: Deprecated, please rename it to fabric_workers. Number of worker processes for Security Fabric daemon.
-            file-mgmt:
+                description: Number of worker processes for Security Fabric daemon.
+            file_mgmt:
+                aliases: ['file-mgmt']
                 type: str
                 description:
-                    - Deprecated, please rename it to file_mgmt.
                     - Enable/disable Security Fabric daemon file management.
                     - disable - Disable daemon file management.
                     - enable - Enable daemon file management.
                 choices:
                     - 'disable'
                     - 'enable'
-            file-quota:
+            file_quota:
+                aliases: ['file-quota']
                 type: int
-                description: Deprecated, please rename it to file_quota. Maximum amount of memory that can be used by the daemon files
-            file-quota-warning:
+                description: Maximum amount of memory that can be used by the daemon files
+            file_quota_warning:
+                aliases: ['file-quota-warning']
                 type: int
-                description: Deprecated, please rename it to file_quota_warning. Warn when the set percentage of quota has been used.
-            fixed-key:
+                description: Warn when the set percentage of quota has been used.
+            fixed_key:
+                aliases: ['fixed-key']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to fixed_key.
-            forticloud-account-enforcement:
+                description: Auto-generated fixed key used when this device is the root.
+            forticloud_account_enforcement:
+                aliases: ['forticloud-account-enforcement']
                 type: str
                 description:
-                    - Deprecated, please rename it to forticloud_account_enforcement.
                     - Fabric FortiCloud account unification.
                     - disable - Disable FortiCloud accound ID matching for Security Fabric.
                     - enable - Enable FortiCloud account ID matching for Security Fabric.
                 choices:
                     - 'disable'
                     - 'enable'
-            group-name:
+            group_name:
+                aliases: ['group-name']
                 type: str
-                description: Deprecated, please rename it to group_name. Security Fabric group name.
-            group-password:
+                description: Security Fabric group name.
+            group_password:
+                aliases: ['group-password']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to group_password.
-            log-unification:
+                description: Security Fabric group password.
+            log_unification:
+                aliases: ['log-unification']
                 type: str
                 description:
-                    - Deprecated, please rename it to log_unification.
                     - Enable/disable broadcast of discovery messages for log unification.
                     - disable - Disable broadcast of discovery messages for log unification.
                     - enable - Enable broadcast of discovery messages for log unification.
                 choices:
                     - 'disable'
                     - 'enable'
-            saml-configuration-sync:
+            saml_configuration_sync:
+                aliases: ['saml-configuration-sync']
                 type: str
                 description:
-                    - Deprecated, please rename it to saml_configuration_sync.
                     - SAML setting configuration synchronization.
                     - local - Do not apply SAML configuration generated by root.
                     - default - SAML setting for fabric members is created by fabric root.
@@ -222,10 +229,11 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            trusted-list:
+            trusted_list:
+                aliases: ['trusted-list']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to trusted_list.
+                description: Trusted list.
                 suboptions:
                     action:
                         type: str
@@ -236,10 +244,10 @@ options:
                         choices:
                             - 'accept'
                             - 'deny'
-                    authorization-type:
+                    authorization_type:
+                        aliases: ['authorization-type']
                         type: str
                         description:
-                            - Deprecated, please rename it to authorization_type.
                             - Authorization type.
                             - serial - Verify downstream by serial number.
                             - certificate - Verify downstream by certificate.
@@ -249,19 +257,20 @@ options:
                     certificate:
                         type: str
                         description: Certificate.
-                    downstream-authorization:
+                    downstream_authorization:
+                        aliases: ['downstream-authorization']
                         type: str
                         description:
-                            - Deprecated, please rename it to downstream_authorization.
                             - Trust authorizations by this node&apos;s administrator.
                             - disable - Disable downstream authorization.
                             - enable - Enable downstream authorization.
                         choices:
                             - 'disable'
                             - 'enable'
-                    ha-members:
+                    ha_members:
+                        aliases: ['ha-members']
                         type: str
-                        description: Deprecated, please rename it to ha_members. HA members.
+                        description: HA members.
                     index:
                         type: int
                         description: Index of the downstream in tree.
@@ -274,15 +283,45 @@ options:
             upstream:
                 type: str
                 description: IP/FQDN of the FortiGate upstream from this FortiGate in the Security Fabric.
-            upstream-port:
+            upstream_port:
+                aliases: ['upstream-port']
                 type: int
-                description: Deprecated, please rename it to upstream_port. The port number to use to communicate with the FortiGate upstream from this...
+                description: The port number to use to communicate with the FortiGate upstream from this FortiGate in the Security Fabric
+            upstream_confirm:
+                aliases: ['upstream-confirm']
+                type: str
+                description:
+                    - Upstream authorization confirm.
+                    - discover - Discover upstream device&apos;s info.
+                    - confirm - Confirm upstream device&apos;s access.
+                choices:
+                    - 'discover'
+                    - 'confirm'
+            ssl_protocol:
+                aliases: ['ssl-protocol']
+                type: str
+                description:
+                    - set the lowest SSL protocol version for upstream and downstream connections.
+                    - follow-global-ssl-protocol - Follow system.
+                    - sslv3 - set SSLv3 as the lowest version.
+                    - tlsv1.
+                    - tlsv1.
+                    - tlsv1.
+                    - tlsv1.
+                choices:
+                    - 'follow-global-ssl-protocol'
+                    - 'sslv3'
+                    - 'tlsv1.0'
+                    - 'tlsv1.1'
+                    - 'tlsv1.2'
+                    - 'tlsv1.3'
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -291,46 +330,46 @@ EXAMPLES = '''
     - name: Add this device to a Security Fabric or set up a new Security Fabric on this device.
       fortinet.fortimanager.fmgr_system_csf:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_csf:
-          accept_auth_by_cert: <value in [disable, enable]>
-          authorization_request_type: <value in [certificate, serial]>
-          certificate: <string>
-          configuration_sync: <value in [default, local]>
-          downstream_access: <value in [disable, enable]>
-          downstream_accprofile: <string>
-          fabric_connector:
-            -
-              accprofile: <string>
-              configuration_write_access: <value in [disable, enable]>
-              serial: <string>
-          fabric_object_unification: <value in [local, default]>
-          fabric_workers: <integer>
-          file_mgmt: <value in [disable, enable]>
-          file_quota: <integer>
-          file_quota_warning: <integer>
-          fixed_key: <list or string>
-          forticloud_account_enforcement: <value in [disable, enable]>
-          group_name: <string>
-          group_password: <list or string>
-          log_unification: <value in [disable, enable]>
-          saml_configuration_sync: <value in [local, default]>
-          status: <value in [disable, enable]>
-          trusted_list:
-            -
-              action: <value in [accept, deny]>
-              authorization_type: <value in [serial, certificate]>
-              certificate: <string>
-              downstream_authorization: <value in [disable, enable]>
-              ha_members: <string>
-              index: <integer>
-              name: <string>
-              serial: <string>
-          upstream: <string>
-          upstream_port: <integer>
+          # accept_auth_by_cert: <value in [disable, enable]>
+          # authorization_request_type: <value in [certificate, serial]>
+          # certificate: <string>
+          # configuration_sync: <value in [default, local]>
+          # downstream_access: <value in [disable, enable]>
+          # downstream_accprofile: <string>
+          # fabric_connector:
+          #   - accprofile: <string>
+          #     configuration_write_access: <value in [disable, enable]>
+          #     serial: <string>
+          # fabric_object_unification: <value in [local, default]>
+          # fabric_workers: <integer>
+          # file_mgmt: <value in [disable, enable]>
+          # file_quota: <integer>
+          # file_quota_warning: <integer>
+          # fixed_key: <list or string>
+          # forticloud_account_enforcement: <value in [disable, enable]>
+          # group_name: <string>
+          # group_password: <list or string>
+          # log_unification: <value in [disable, enable]>
+          # saml_configuration_sync: <value in [local, default]>
+          # status: <value in [disable, enable]>
+          # trusted_list:
+          #   - action: <value in [accept, deny]>
+          #     authorization_type: <value in [serial, certificate]>
+          #     certificate: <string>
+          #     downstream_authorization: <value in [disable, enable]>
+          #     ha_members: <string>
+          #     index: <integer>
+          #     name: <string>
+          #     serial: <string>
+          # upstream: <string>
+          # upstream_port: <integer>
+          # upstream_confirm: <value in [discover, confirm]>
+          # ssl_protocol: <value in [follow-global-ssl-protocol, sslv3, tlsv1.0, ...]>
 '''
 
 RETURN = '''
@@ -374,21 +413,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/csf'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/csf/{csf}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -399,7 +431,7 @@ def main():
                 'accept-auth-by-cert': {'v_range': [['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'authorization-request-type': {'v_range': [['7.4.1', '']], 'choices': ['certificate', 'serial'], 'type': 'str'},
                 'certificate': {'v_range': [['7.4.1', '']], 'type': 'str'},
-                'configuration-sync': {'v_range': [['7.4.1', '']], 'choices': ['default', 'local'], 'type': 'str'},
+                'configuration-sync': {'v_range': [['7.4.1', '7.4.3']], 'choices': ['default', 'local'], 'type': 'str'},
                 'downstream-access': {'v_range': [['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'downstream-accprofile': {'v_range': [['7.4.1', '']], 'type': 'str'},
                 'fabric-connector': {
@@ -412,17 +444,17 @@ def main():
                     },
                     'elements': 'dict'
                 },
-                'fabric-object-unification': {'v_range': [['7.4.1', '']], 'choices': ['local', 'default'], 'type': 'str'},
+                'fabric-object-unification': {'v_range': [['7.4.1', '7.4.3']], 'choices': ['local', 'default'], 'type': 'str'},
                 'fabric-workers': {'v_range': [['7.4.1', '']], 'type': 'int'},
-                'file-mgmt': {'v_range': [['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'file-quota': {'v_range': [['7.4.1', '']], 'type': 'int'},
-                'file-quota-warning': {'v_range': [['7.4.1', '']], 'type': 'int'},
+                'file-mgmt': {'v_range': [['7.4.1', '7.4.3']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'file-quota': {'v_range': [['7.4.1', '7.4.3']], 'type': 'int'},
+                'file-quota-warning': {'v_range': [['7.4.1', '7.4.3']], 'type': 'int'},
                 'fixed-key': {'v_range': [['7.4.1', '']], 'no_log': True, 'type': 'list', 'elements': 'str'},
                 'forticloud-account-enforcement': {'v_range': [['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'group-name': {'v_range': [['7.4.1', '']], 'type': 'str'},
                 'group-password': {'v_range': [['7.4.1', '']], 'no_log': True, 'type': 'list', 'elements': 'str'},
                 'log-unification': {'v_range': [['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'saml-configuration-sync': {'v_range': [['7.4.1', '']], 'choices': ['local', 'default'], 'type': 'str'},
+                'saml-configuration-sync': {'v_range': [['7.4.1', '7.4.3']], 'choices': ['local', 'default'], 'type': 'str'},
                 'status': {'v_range': [['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'trusted-list': {
                     'v_range': [['7.4.1', '']],
@@ -440,9 +472,14 @@ def main():
                     'elements': 'dict'
                 },
                 'upstream': {'v_range': [['7.4.1', '']], 'type': 'str'},
-                'upstream-port': {'v_range': [['7.4.1', '']], 'type': 'int'}
+                'upstream-port': {'v_range': [['7.4.1', '']], 'type': 'int'},
+                'upstream-confirm': {'v_range': [['7.6.0', '']], 'choices': ['discover', 'confirm'], 'type': 'str'},
+                'ssl-protocol': {
+                    'v_range': [['7.4.4', '7.4.8'], ['7.6.2', '']],
+                    'choices': ['follow-global-ssl-protocol', 'sslv3', 'tlsv1.0', 'tlsv1.1', 'tlsv1.2', 'tlsv1.3'],
+                    'type': 'str'
+                }
             }
-
         }
     }
 
@@ -451,17 +488,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_csf'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
