@@ -16,7 +16,6 @@ short_description: Global range attributes.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "1.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -247,6 +246,7 @@ options:
                     - 'siem'
                     - 'soc'
                     - 'ai'
+                    - 'safeguard-mv'
             enc_algorithm:
                 aliases: ['enc-algorithm']
                 type: str
@@ -1279,11 +1279,66 @@ options:
                     - 'tlsv1.1'
                     - 'tlsv1.2'
                     - 'tlsv1.3'
+            apache_wsgi_processes:
+                aliases: ['apache-wsgi-processes']
+                type: int
+                description: Apache wsgi processes.
+            fmg_fabric_port:
+                aliases: ['fmg-fabric-port']
+                type: int
+                description: Fmg fabric port.
+            gui_feature_visibility_mode:
+                aliases: ['gui-feature-visibility-mode']
+                type: str
+                description: Gui feature visibility mode.
+                choices:
+                    - 'per-adom'
+                    - 'per-admin'
+            storage_age_limit:
+                aliases: ['storage-age-limit']
+                type: int
+                description: Storage age limit.
+            fgfm_allow_vm:
+                aliases: ['fgfm-allow-vm']
+                type: str
+                description:
+                    - Enable/disable VM platform FGFM connect restriction.
+                    - disable - Don&apos;t allow VM platform connection in FGFM.
+                    - enable - Allow VM platform connection in FGFM.
+                choices:
+                    - 'disable'
+                    - 'enable'
+            hitcount_response_timeout:
+                aliases: ['hitcount-response-timeout']
+                type: int
+                description: Timeout of waiting for hitcount response
+            rpc_log:
+                aliases: ['rpc-log']
+                type: str
+                description:
+                    - Enable/Disable incoming/outgoing rpc log.
+                    - disable - Disable rpc log.
+                    - enable - Enable rpc log
+                choices:
+                    - 'disable'
+                    - 'enable'
+            auth_dev_restapi_allowlist:
+                aliases: ['auth-dev-restapi-allowlist']
+                type: str
+                description: Auth dev restapi allowlist.
+                choices:
+                    - 'disable'
+                    - 'enable'
+            gui_install_preview_concurrency:
+                aliases: ['gui-install-preview-concurrency']
+                type: int
+                description: Set the maximum number of devices to be processed in a single GUI install preview request
 '''
 
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -1293,8 +1348,8 @@ EXAMPLES = '''
     - name: Enable workspace mode
       fortinet.fortimanager.fmgr_system_global:
         system_global:
-          adom-status: enable
-          workspace-mode: normal
+          adom_status: enable
+          workspace_mode: normal
 
     - name: Script table.
       fortinet.fortimanager.fmgr_dvmdb_script:
@@ -1321,8 +1376,8 @@ EXAMPLES = '''
     - name: Restore workspace mode
       fortinet.fortimanager.fmgr_system_global:
         system_global:
-          adom-status: enable
-          workspace-mode: disabled
+          adom_status: enable
+          workspace_mode: disabled
 '''
 
 RETURN = '''
@@ -1399,7 +1454,11 @@ def main():
                 'detect-unregistered-log-device': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'device-view-mode': {'choices': ['regular', 'tree'], 'type': 'str'},
                 'dh-params': {'choices': ['1024', '1536', '2048', '3072', '4096', '6144', '8192'], 'type': 'str'},
-                'disable-module': {'type': 'list', 'choices': ['fortiview-noc', 'none', 'fortirecorder', 'siem', 'soc', 'ai'], 'elements': 'str'},
+                'disable-module': {
+                    'type': 'list',
+                    'choices': ['fortiview-noc', 'none', 'fortirecorder', 'siem', 'soc', 'ai', 'safeguard-mv'],
+                    'elements': 'str'
+                },
                 'enc-algorithm': {'choices': ['low', 'medium', 'high', 'custom'], 'type': 'str'},
                 'faz-status': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'fgfm-local-cert': {'type': 'str'},
@@ -1432,7 +1491,7 @@ def main():
                 'search-all-adoms': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'ssl-low-encryption': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'ssl-protocol': {
-                    'v_range': [['6.0.0', '7.4.3'], ['7.6.0', '']],
+                    'v_range': [['6.0.0', '7.4.3'], ['7.6.0', '7.6.1']],
                     'type': 'list',
                     'choices': ['tlsv1.2', 'tlsv1.1', 'tlsv1.0', 'sslv3', 'tlsv1.3'],
                     'elements': 'str'
@@ -1483,28 +1542,28 @@ def main():
                     },
                     'elements': 'dict'
                 },
-                'gui-curl-timeout': {'v_range': [['6.4.11', '6.4.15'], ['7.0.7', '7.0.13'], ['7.2.2', '']], 'type': 'int'},
+                'gui-curl-timeout': {'v_range': [['6.4.11', '6.4.15'], ['7.0.7', '7.0.15'], ['7.2.2', '']], 'type': 'int'},
                 'fgfm-cert-exclusive': {
-                    'v_range': [['6.4.15', '6.4.15'], ['7.0.12', '7.0.13'], ['7.2.2', '']],
+                    'v_range': [['6.4.15', '6.4.15'], ['7.0.12', '7.0.15'], ['7.2.2', '']],
                     'choices': ['disable', 'enable'],
                     'type': 'str'
                 },
                 'fgfm-deny-unknown': {
-                    'v_range': [['6.4.15', '6.4.15'], ['7.0.12', '7.0.13'], ['7.2.5', '7.2.8'], ['7.4.3', '']],
+                    'v_range': [['6.4.15', '6.4.15'], ['7.0.12', '7.0.15'], ['7.2.5', '7.2.11'], ['7.4.3', '']],
                     'choices': ['disable', 'enable'],
                     'type': 'str'
                 },
                 'fgfm-peercert-withoutsn': {
-                    'v_range': [['6.4.15', '6.4.15'], ['7.0.12', '7.0.13'], ['7.2.5', '7.2.8'], ['7.4.3', '']],
+                    'v_range': [['6.4.15', '6.4.15'], ['7.0.12', '7.0.15'], ['7.2.5', '7.2.9'], ['7.4.3', '7.4.5'], ['7.6.0', '7.6.1']],
                     'choices': ['disable', 'enable'],
                     'type': 'str'
                 },
-                'table-entry-blink': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'contentpack-fgt-install': {'v_range': [['7.0.5', '7.0.13'], ['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'gui-polling-interval': {'v_range': [['7.0.5', '7.0.13'], ['7.2.1', '']], 'type': 'int'},
-                'no-copy-permission-check': {'v_range': [['7.0.8', '7.0.13'], ['7.2.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'table-entry-blink': {'v_range': [['7.0.4', '7.0.15'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'contentpack-fgt-install': {'v_range': [['7.0.5', '7.0.15'], ['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'gui-polling-interval': {'v_range': [['7.0.5', '7.0.15'], ['7.2.1', '']], 'type': 'int'},
+                'no-copy-permission-check': {'v_range': [['7.0.8', '7.0.15'], ['7.2.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'ssh-enc-algo': {
-                    'v_range': [['7.0.11', '7.0.13'], ['7.2.5', '7.2.8'], ['7.4.2', '']],
+                    'v_range': [['7.0.11', '7.0.15'], ['7.2.5', '7.2.11'], ['7.4.2', '']],
                     'type': 'list',
                     'choices': [
                         'chacha20-poly1305@openssh.com', 'aes128-ctr', 'aes192-ctr', 'aes256-ctr', 'arcfour256', 'arcfour128', 'aes128-cbc', '3des-cbc',
@@ -1514,13 +1573,13 @@ def main():
                     'elements': 'str'
                 },
                 'ssh-hostkey-algo': {
-                    'v_range': [['7.0.11', '7.0.13'], ['7.2.5', '7.2.8'], ['7.4.2', '']],
+                    'v_range': [['7.0.11', '7.0.15'], ['7.2.5', '7.2.11'], ['7.4.2', '']],
                     'type': 'list',
                     'choices': ['ssh-rsa', 'ecdsa-sha2-nistp521', 'rsa-sha2-256', 'rsa-sha2-512', 'ssh-ed25519'],
                     'elements': 'str'
                 },
                 'ssh-kex-algo': {
-                    'v_range': [['7.0.11', '7.0.13'], ['7.2.5', '7.2.8'], ['7.4.2', '']],
+                    'v_range': [['7.0.11', '7.0.15'], ['7.2.5', '7.2.11'], ['7.4.2', '']],
                     'type': 'list',
                     'choices': [
                         'diffie-hellman-group1-sha1', 'diffie-hellman-group14-sha1', 'diffie-hellman-group14-sha256', 'diffie-hellman-group16-sha512',
@@ -1530,7 +1589,7 @@ def main():
                     'elements': 'str'
                 },
                 'ssh-mac-algo': {
-                    'v_range': [['7.0.11', '7.0.13'], ['7.2.5', '7.2.8'], ['7.4.2', '']],
+                    'v_range': [['7.0.11', '7.0.15'], ['7.2.5', '7.2.11'], ['7.4.2', '']],
                     'type': 'list',
                     'choices': [
                         'hmac-md5', 'hmac-md5-etm@openssh.com', 'hmac-md5-96', 'hmac-md5-96-etm@openssh.com', 'hmac-sha1', 'hmac-sha1-etm@openssh.com',
@@ -1541,38 +1600,51 @@ def main():
                     'elements': 'str'
                 },
                 'ssh-strong-crypto': {
-                    'v_range': [['7.0.11', '7.0.13'], ['7.2.5', '7.2.8'], ['7.4.2', '']],
+                    'v_range': [['7.0.11', '7.0.15'], ['7.2.5', '7.2.11'], ['7.4.2', '7.6.3']],
                     'choices': ['disable', 'enable'],
                     'type': 'str'
                 },
                 'admin-lockout-method': {'v_range': [['7.2.2', '']], 'choices': ['ip', 'user'], 'type': 'str'},
                 'workspace-unlock-after-install': {'v_range': [['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'log-checksum-upload': {'v_range': [['7.2.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'apache-mode': {'v_range': [['7.2.4', '7.2.8'], ['7.4.1', '']], 'choices': ['event', 'prefork'], 'type': 'str'},
-                'no-vip-value-check': {'v_range': [['7.2.4', '7.2.8'], ['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'apache-mode': {'v_range': [['7.2.4', '7.2.11'], ['7.4.1', '']], 'choices': ['event', 'prefork'], 'type': 'str'},
+                'no-vip-value-check': {'v_range': [['7.2.4', '7.2.11'], ['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'fortiservice-port': {'v_range': [['7.4.1', '']], 'type': 'int'},
                 'management-ip': {'v_range': [['7.4.1', '']], 'type': 'str'},
                 'management-port': {'v_range': [['7.4.1', '']], 'type': 'int'},
                 'save-last-hit-in-adomdb': {'v_range': [['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'api-ip-binding': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'admin-host': {'v_range': [['7.4.4', '']], 'type': 'str'},
-                'admin-ssh-grace-time': {'v_range': [['7.2.6', '7.2.8'], ['7.4.4', '']], 'type': 'int'},
+                'admin-ssh-grace-time': {'v_range': [['7.2.6', '7.2.11'], ['7.4.4', '']], 'type': 'int'},
                 'fabric-storage-pool-quota': {'v_range': [['7.6.0', '']], 'type': 'int'},
                 'fabric-storage-pool-size': {'v_range': [['7.6.0', '']], 'type': 'int'},
-                'fcp-cfg-service': {'v_range': [['7.2.6', '7.2.8'], ['7.4.4', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'fcp-cfg-service': {'v_range': [['7.2.6', '7.2.11'], ['7.4.4', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'jsonapi-log': {'v_range': [['7.6.0', '']], 'choices': ['disable', 'request', 'response', 'all'], 'type': 'str'},
-                'global-ssl-protocol': {'v_range': [['7.4.4', '7.4.5']], 'choices': ['sslv3', 'tlsv1.0', 'tlsv1.1', 'tlsv1.2', 'tlsv1.3'], 'type': 'str'},
+                'global-ssl-protocol': {
+                    'v_range': [['7.4.4', '7.4.8'], ['7.6.2', '']],
+                    'choices': ['sslv3', 'tlsv1.0', 'tlsv1.1', 'tlsv1.2', 'tlsv1.3'],
+                    'type': 'str'
+                },
                 'httpd-ssl-protocol': {
-                    'v_range': [['7.4.4', '7.4.5']],
+                    'v_range': [['7.4.4', '7.4.8'], ['7.6.2', '']],
                     'type': 'list',
                     'choices': ['sslv3', 'tlsv1.0', 'tlsv1.1', 'tlsv1.2', 'tlsv1.3'],
                     'elements': 'str'
                 },
                 'mapclient-ssl-protocol': {
-                    'v_range': [['7.4.4', '7.4.5']],
+                    'v_range': [['7.4.4', '7.4.8'], ['7.6.2', '']],
                     'choices': ['follow-global-ssl-protocol', 'sslv3', 'tlsv1.0', 'tlsv1.1', 'tlsv1.2', 'tlsv1.3'],
                     'type': 'str'
-                }
+                },
+                'apache-wsgi-processes': {'v_range': [['7.2.10', '7.2.11'], ['7.4.6', '7.4.8'], ['7.6.2', '']], 'type': 'int'},
+                'fmg-fabric-port': {'v_range': [['7.6.2', '']], 'type': 'int'},
+                'gui-feature-visibility-mode': {'v_range': [['7.4.7', '7.4.8'], ['7.6.2', '']], 'choices': ['per-adom', 'per-admin'], 'type': 'str'},
+                'storage-age-limit': {'v_range': [['7.6.2', '']], 'type': 'int'},
+                'fgfm-allow-vm': {'v_range': [['7.2.10', '7.2.11'], ['7.4.7', '7.4.8'], ['7.6.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'hitcount-response-timeout': {'v_range': [['7.4.7', '7.4.8'], ['7.6.4', '']], 'type': 'int'},
+                'rpc-log': {'v_range': [['7.4.7', '7.4.8'], ['7.6.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'auth-dev-restapi-allowlist': {'v_range': [['7.6.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'gui-install-preview-concurrency': {'v_range': [['7.4.8', '7.4.8'], ['7.6.4', '']], 'type': 'int'}
             }
         }
     }
