@@ -16,7 +16,6 @@ short_description: Configure replacement message groups.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -1170,7 +1169,7 @@ def main():
                         'format': {'choices': ['none', 'text', 'html', 'wml'], 'type': 'str'},
                         'header': {'choices': ['none', 'http', '8bit'], 'type': 'str'},
                         'msg-type': {'type': 'str'},
-                        'id': {'v_range': [['6.4.11', '6.4.15'], ['7.0.6', '7.0.14'], ['7.2.3', '']], 'type': 'int'}
+                        'id': {'v_range': [['6.4.11', '6.4.15'], ['7.0.6', '7.0.15'], ['7.2.3', '']], 'type': 'int'}
                     },
                     'elements': 'dict'
                 },
@@ -1206,13 +1205,13 @@ def main():
                     'elements': 'dict'
                 },
                 'ec': {
-                    'v_range': [['6.0.0', '7.2.1']],
+                    'v_range': [['6.0.0', '7.2.1'], ['7.4.8', '7.4.8']],
                     'type': 'list',
                     'options': {
-                        'buffer': {'v_range': [['6.0.0', '7.2.1']], 'type': 'str'},
-                        'format': {'v_range': [['6.0.0', '7.2.1']], 'choices': ['none', 'text', 'html', 'wml'], 'type': 'str'},
-                        'header': {'v_range': [['6.0.0', '7.2.1']], 'choices': ['none', 'http', '8bit'], 'type': 'str'},
-                        'msg-type': {'v_range': [['6.0.0', '7.2.1']], 'type': 'str'}
+                        'buffer': {'v_range': [['6.0.0', '7.2.1'], ['7.4.8', '7.4.8']], 'type': 'str'},
+                        'format': {'v_range': [['6.0.0', '7.2.1'], ['7.4.8', '7.4.8']], 'choices': ['none', 'text', 'html', 'wml'], 'type': 'str'},
+                        'header': {'v_range': [['6.0.0', '7.2.1'], ['7.4.8', '7.4.8']], 'choices': ['none', 'http', '8bit'], 'type': 'str'},
+                        'msg-type': {'v_range': [['6.0.0', '7.2.1'], ['7.4.8', '7.4.8']], 'type': 'str'}
                     },
                     'elements': 'dict'
                 },
@@ -1409,7 +1408,7 @@ def main():
                         'format': {'choices': ['none', 'text', 'html', 'wml'], 'type': 'str'},
                         'header': {'choices': ['none', 'http', '8bit'], 'type': 'str'},
                         'msg-type': {'type': 'str'},
-                        'id': {'v_range': [['6.4.11', '6.4.15'], ['7.0.6', '7.0.14'], ['7.2.3', '']], 'type': 'int'}
+                        'id': {'v_range': [['6.4.11', '6.4.15'], ['7.0.6', '7.0.15'], ['7.2.3', '']], 'type': 'int'}
                     },
                     'elements': 'dict'
                 },
