@@ -16,7 +16,6 @@ short_description: Replacement message table entries.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -126,6 +128,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -136,13 +139,13 @@ EXAMPLES = '''
       fortinet.fortimanager.fmgr_system_replacemsggroup_alertmail:
         bypass_validation: false
         adom: ansible
-        replacemsg-group: ansible-test # name
+        replacemsg_group: ansible-test # name
         state: present
         system_replacemsggroup_alertmail:
           buffer: ansible-buffer
           format: none # <value in [none, text, html, ...]>
           header: http # <value in [none, http, 8bit]>
-          msg-type: ansible-msgtype # required
+          msg_type: ansible-msgtype # required
 
 - name: Gathering fortimanager facts
   hosts: fortimanagers
@@ -159,7 +162,7 @@ EXAMPLES = '''
           selector: "system_replacemsggroup_alertmail"
           params:
             adom: "ansible"
-            replacemsg-group: "ansible-test" # name
+            replacemsg_group: "ansible-test" # name
             alertmail: "your_value"
 '''
 
@@ -219,6 +222,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'replacemsg-group': {'type': 'str', 'api_name': 'replacemsg_group'},
         'replacemsg_group': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'system_replacemsggroup_alertmail': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -227,7 +231,7 @@ def main():
                 'format': {'choices': ['none', 'text', 'html', 'wml'], 'type': 'str'},
                 'header': {'choices': ['none', 'http', '8bit'], 'type': 'str'},
                 'msg-type': {'required': True, 'type': 'str'},
-                'id': {'v_range': [['6.4.11', '6.4.15'], ['7.0.6', '7.0.13'], ['7.2.3', '']], 'type': 'int'}
+                'id': {'v_range': [['6.4.11', '6.4.15'], ['7.0.6', '7.0.15'], ['7.2.3', '']], 'type': 'int'}
             }
         }
     }
