@@ -16,7 +16,6 @@ short_description: Device list.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.2.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -114,6 +116,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -122,17 +125,17 @@ EXAMPLES = '''
     - name: Device list.
       fortinet.fortimanager.fmgr_user_deviceaccesslist_devicelist:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         device_access_list: <your own value>
         state: present # <value in [present, absent]>
         user_deviceaccesslist_devicelist:
-          action: <value in [deny, accept]>
-          device: <string>
-          id: <integer>
+          id: 0 # Required variable, integer
+          # action: <value in [deny, accept]>
+          # device: <string>
 '''
 
 RETURN = '''
@@ -176,29 +179,22 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/user/device-access-list/{device-access-list}/device-list',
         '/pm/config/global/obj/user/device-access-list/{device-access-list}/device-list'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/user/device-access-list/{device-access-list}/device-list/{device-list}',
-        '/pm/config/global/obj/user/device-access-list/{device-access-list}/device-list/{device-list}'
-    ]
-
     url_params = ['adom', 'device-access-list']
     module_primary_key = 'id'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'device-access-list': {'type': 'str', 'api_name': 'device_access_list'},
         'device_access_list': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'user_deviceaccesslist_devicelist': {
             'type': 'dict',
             'v_range': [['6.2.2', '7.2.1']],
@@ -207,7 +203,6 @@ def main():
                 'device': {'v_range': [['6.2.2', '7.2.1']], 'type': 'str'},
                 'id': {'v_range': [['6.2.2', '7.2.1']], 'required': True, 'type': 'int'}
             }
-
         }
     }
 
@@ -216,17 +211,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'user_deviceaccesslist_devicelist'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
