@@ -16,7 +16,6 @@ short_description: POP3 server entry configuration.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -122,6 +124,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -138,7 +141,7 @@ EXAMPLES = '''
           # port: 8000
           # secure: none # <value in [none, starttls, pop3s]>
           # server: ansible
-          # ssl-min-proto-version: default # <value in [default, TLSv1, TLSv1-1, ...]>
+          # ssl_min_proto_version: default # <value in [default, TLSv1, TLSv1-1, ...]>
 
 - name: Gathering fortimanager facts
   hosts: fortimanagers
@@ -212,6 +215,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'user_pop3': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
