@@ -16,7 +16,6 @@ short_description: Configure local FortiGuard Web Filter local ratings.
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
-
 version_added: "2.0.0"
 author:
     - Xinwei Du (@dux-fortinet)
@@ -73,6 +72,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -111,6 +113,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -119,17 +122,17 @@ EXAMPLES = '''
     - name: Configure local FortiGuard Web Filter local ratings.
       fortinet.fortimanager.fmgr_webfilter_ftgdlocalrating:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         webfilter_ftgdlocalrating:
-          rating: <list or string>
-          status: <value in [disable, enable]>
-          url: <string>
-          comment: <string>
+          rating: "your value" # Required variable, string
+          # status: <value in [disable, enable]>
+          # url: <string>
+          # comment: <string>
 '''
 
 RETURN = '''
@@ -186,6 +189,7 @@ def main():
     module_primary_key = 'rating'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'webfilter_ftgdlocalrating': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
