@@ -20,43 +20,21 @@ version_added: '3.2.0'
 author:
   - Hitachi Vantara, LTD. (@hitachi-vantara)
 requirements:
-  - python >= 3.8
+  - python >= 3.9
 attributes:
   check_mode:
     description: Determines if the module should run in check mode.
     support: none
 extends_documentation_fragment:
 - hitachivantara.vspone_block.common.gateway_note
+- hitachivantara.vspone_block.common.connection_with_type
 options:
   state:
-    description: The level of the HUR pairs task. Choices are C(present), C(absent), C(update).
+    description: The level of the HUR pairs task. Choices are C(present), C(absent), C(update), (assign_clpr_id).
     type: str
     required: false
-    choices: ['present', 'absent', 'update']
+    choices: ['present', 'absent', 'update', 'assign_clpr_id']
     default: 'present'
-  connection_info:
-    description: Information required to establish a connection to the storage system.
-    type: dict
-    required: true
-    suboptions:
-      address:
-        description: IP address or hostname of the storage system.
-        type: str
-        required: true
-      username:
-        description: Username for authentication. This is a required field.
-        type: str
-        required: false
-      password:
-        description: Password for authentication. This is a required field.
-        type: str
-        required: false
-      connection_type:
-        description: Type of connection to the storage system.
-        type: str
-        required: false
-        choices: ['direct']
-        default: 'direct'
   spec:
     description: Specification for the parity group tasks.
     type: dict
@@ -64,31 +42,43 @@ options:
     suboptions:
       parity_group_id:
         description: The parity group number of the parity group to retrieve.
+          Required for the Create parity group
+          /Delete parity group
+          /Update parity group
+          /Assign CLPR ID to Parity Group tasks.
         type: str
         required: false
       drive_location_ids:
         description: Specify the locations of the drives to be used to create to the parity group.
+          Required for the Create parity group task.
         type: list
         elements: str
         required: false
       raid_type:
         description: RAID type.
+          Required for the Create parity group task.
         type: str
         required: false
       is_encryption_enabled:
         description: Specify whether to enable the encryption function for the parity group.
+          Optional for the Create parity group task.
         type: bool
         required: false
       is_copy_back_mode_enabled:
         description: Specify whether to enable the encryption function for the parity group.
+          Optional for the Create parity group task.
         type: bool
         required: false
       is_accelerated_compression_enabled:
         description: Specify whether to enable accelerated compression for the parity group.
+          Optional for the Create parity group
+          /Update parity group tasks.
         type: bool
         required: false
       clpr_id:
         description: Specify a CLPR number in the range from 0 to 31.
+          Required for the Create parity group
+          /Assign CLPR ID to Parity Group tasks.
         type: int
         required: false
 """
@@ -130,6 +120,17 @@ EXAMPLES = """
     spec:
       parity_group_id: 1-10
       is_accelerated_compression_enabled: true
+
+- name: Assign CLPR Id to parity group
+  hitachivantara.vspone_block.vsp.hv_paritygroup:
+    connection_info:
+      address: storage1.company.com
+      username: "admin"
+      password: "secret"
+    state: "update"
+    spec:
+      parity_group_id: 1-10
+      clpr_id: 0
 """
 
 RETURN = """
@@ -144,17 +145,21 @@ parity_group:
       type: int
       sample: 0
     copyback_mode:
-      description: Indicates if copyback mode is enabled.
+      description: Indicates if copy back mode is enabled.
       type: bool
-      sample: false
+      sample: true
     drive_type:
       description: Type of drive.
       type: str
       sample: "SSD"
     free_capacity:
-      description: Free capacity of the parity group.
+      description: Free capacity of the parity group (human readable).
       type: str
-      sample: "5.16TB"
+      sample: "0"
+    free_capacity_mb:
+      description: Free capacity of the parity group in MB.
+      type: float
+      sample: 0.0
     is_accelerated_compression:
       description: Indicates if accelerated compression is enabled.
       type: bool
@@ -162,7 +167,7 @@ parity_group:
     is_encryption_enabled:
       description: Indicates if encryption is enabled.
       type: bool
-      sample: true
+      sample: false
     is_pool_array_group:
       description: Indicates if it is a pool array group.
       type: bool
@@ -171,11 +176,12 @@ parity_group:
       description: List of LDEV IDs.
       type: list
       elements: int
-      sample: []
+      sample:
+        - 32732
     parity_group_id:
       description: Parity group ID.
       type: str
-      sample: "1-10"
+      sample: "1-2"
     raid_level:
       description: RAID level.
       type: str
@@ -183,7 +189,7 @@ parity_group:
     resource_group_id:
       description: Resource group ID.
       type: int
-      sample: null
+      sample: -1
     resource_id:
       description: Resource ID.
       type: int
@@ -193,9 +199,13 @@ parity_group:
       type: str
       sample: null
     total_capacity:
-      description: Total capacity of the parity group.
+      description: Total capacity of the parity group (human readable).
       type: str
-      sample: "5.16TB"
+      sample: "15.46TB"
+    total_capacity_mb:
+      description: Total capacity of the parity group in MB.
+      type: float
+      sample: 16210984.96
 """
 
 from ansible.module_utils.basic import AnsibleModule
